@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** $Id: config.h,v 1.42.2.1 2005/02/28 22:10:40 tilo Exp $
+** $Id$
 **
 ** Copyright (C) 2001-2005 Tilo Riemer <riemer@lincvs.org>,
 **                         Frank Hemer <frank@hemer.org> and
@@ -85,17 +85,17 @@
 #define TIME_WITH_SYS_TIME
 
 /* application name */
-const char LC_APPNAME[] = "LinCVS";
+extern const char LC_APPNAME[];
 
 /* Version number of package */
-const char LC_VERSION[] = "1.4.0";
+extern const char LC_VERSION[];
 
-const char LC_HELP_DIR[]     = "Help";       //contains some docs like README
-const char LC_TRANSLATIONS_SUBDIR[] = "Translations"; //used as subdir in Help
-const char LC_MESSAGES_DIR[] = "Messages";   //contains translations as qm files
-const char LC_TOOLS_DIR[]    = "Tools";      //contains helper programs for ssh
+extern const char LC_HELP_DIR[];            //contains some docs like README
+extern const char LC_TRANSLATIONS_SUBDIR[]; //used as subdir in Help
+extern const char LC_MESSAGES_DIR[];        //contains translations as qm files
+extern const char LC_TOOLS_DIR[];           //contains helper programs for ssh
 
-const char LC_LOG_FILE[]     = "lincvs.log"; //name of logfile
+extern const char LC_LOG_FILE[];            //name of logfile
 
 
 //only needed if we support qt < 3.1.0
@@ -129,3 +129,4 @@ CEXTERN QString getVersion();
 CEXTERN QString getCompileTime();
 
 #endif //CONFIG_H_20020325
+
