@@ -101,6 +101,8 @@ const char CvsConfig::cvsPath[]                 = "/lincvs/CvsPath";
 const char CvsConfig::cvsVersion[]              = "/lincvs/CvsVersion";
 const char CvsConfig::useDirWatch[]             = "/lincvs/useDirWatch";
 
+const char CvsConfig::SshKeyList[]              = "/lincvs/SshKeyList";
+const char CvsConfig::SshAgent[]                = "/lincvs/SshAgent";
 const char CvsConfig::RemoteBrowser[]		= "/lincvs/remoteBrowser";
 const char CvsConfig::LocalBrowser[]	        = "/lincvs/localBrowser";
 const char CvsConfig::CVSRsh[]                  = "/lincvs/cvsRsh";
@@ -193,8 +195,9 @@ const char CvsConfig::FontDiff[]                = "/lincvs/Font/Diff";
 const char CvsConfig::TextEncoder[]             = "/lincvs/I18n/TextEncoder";
 const char CvsConfig::TextDecoder[]             = "/lincvs/I18n/TextDecoder";
 
-const char CvsConfig::defCvsVersion[]           = "cvs";
 #ifdef Q_WS_MAC
+const char CvsConfig::defCvsVersion[]           = "ocvs";
+const char CvsConfig::defSshAgent[]             = "start-ssh-agent.sh";
 const char CvsConfig::defRemoteBrowser[]	= "open";
 const char CvsConfig::defLocalBrowser[]		= "open";
 const char CvsConfig::defOpenFileList[]         = "*\nopen\n%n\n-";
@@ -202,6 +205,8 @@ const char CvsConfig::defViewFileList[]         = "*\nopen\n%n\n-";
 const char CvsConfig::defLocalShell[]           = "/Applications/Utilities/Terminal";
 #else
 #ifdef Q_WS_X11
+const char CvsConfig::defCvsVersion[]           = "cvs";
+const char CvsConfig::defSshAgent[]             = "start-ssh-agent.sh";
 const char CvsConfig::defRemoteBrowser[]	= "mozilla";
 const char CvsConfig::defLocalBrowser[]		= "mozilla";
 const char CvsConfig::defOpenFileList[]         = "*\nxterm\n-e vi %1\n-";
@@ -209,6 +214,8 @@ const char CvsConfig::defViewFileList[]         = "*\nxterm\n-e more %1\n-";
 const char CvsConfig::defLocalShell[]           = "xterm";
 #else
 #ifdef Q_WS_QWS
+const char CvsConfig::defCvsVersion[]           = "cvs";
+const char CvsConfig::defSshAgent[]             = "";
 const char CvsConfig::defRemoteBrowser[]	= "";
 const char CvsConfig::defLocalBrowser[]		= "";
 const char CvsConfig::defOpenFileList[]         = "";
@@ -237,6 +244,9 @@ CvsConfig::CvsConfig()
    m_pSettings = new QSettings();
 #ifdef Q_WS_X11
    if (!Misc::g_rcPath.isEmpty()) m_pSettings->insertSearchPath(QSettings::Unix, Misc::g_rcPath);
+#endif
+#ifdef Q_WS_MAC
+   m_pSettings->setPath("lincvs.com", "LinCVS", QSettings::User);
 #endif
    readCfg();
 }
@@ -567,73 +577,68 @@ void CvsConfig::writeCfg()
 //----------------------------------------------------------------------------
 
 void CvsConfig::readProjectSettings( QString projectPath) {
-
-   unsigned int i = 0;
-   QStringList projectList = m_pSettings->subkeyList( projectPath);
-
-   if (projectList.isEmpty()) {//fallback to old project settings model, will be removed in near future
-
-      QStringList projectNameList     = m_pSettings->readListEntry("/lincvs/Workbench/projectList");
-      QStringList projectDisabledList = m_pSettings->readListEntry("/lincvs/Workbench/projectDisabledList");
-
-      for( i = 0; i < projectNameList.count(); i++) {
-
-#ifdef Q_WS_WIN
-	 projectNameList[i].replace(QRegExp ("\\\\"), "/");
-#endif
-	 QString projectName = projectNameList[i].mid(projectNameList[i].findRev("/")+1);
-	 projectSettings->set( projectName,WORKDIR,projectNameList[i]);
-      
-	 QStringList::iterator it;
-	 QStringList disabled;
-	 for ( it = projectDisabledList.begin(); it != projectDisabledList.end(); ++it ) {
-	    if ((*it).startsWith(projectNameList[i]) &&
-		  ( ((*it).length() == projectNameList[i].length()) ||
-			((*it).at(projectNameList[i].length())=='/'))) {
-
-	       disabled.append(*it);
-
-	    }
-	 }
-	 projectSettings->set( projectName,DISABLED,disabled);
-      }
-      return;
-   }
-
-   projectSettings->readFromSettings( m_pSettings, projectPath);
-
+    
+    unsigned int i = 0;
+    QStringList projectList = m_pSettings->subkeyList( projectPath);
+    
+    if (projectList.isEmpty()) {//fallback to old project settings model, will be removed in near future
+        
+        QStringList projectNameList     = m_pSettings->readListEntry("/lincvs/Workbench/projectList");
+        QStringList projectDisabledList = m_pSettings->readListEntry("/lincvs/Workbench/projectDisabledList");
+        
+        for( i = 0; i < projectNameList.count(); i++) {
+            
+            QString projectName = projectNameList[i].mid(projectNameList[i].findRev("/")+1);
+            projectSettings->set( projectName,WORKDIR,projectNameList[i]);
+            
+            QStringList::iterator it;
+            QStringList disabled;
+            for ( it = projectDisabledList.begin(); it != projectDisabledList.end(); ++it ) {
+                if ((*it).startsWith(projectNameList[i]) &&
+                    ( ((*it).length() == projectNameList[i].length()) ||
+                      ((*it).at(projectNameList[i].length())=='/'))) {
+                    
+                    disabled.append(*it);
+                    
+                }
+            }
+            projectSettings->set( projectName,DISABLED,disabled);
+        }
+        return;
+    }
+    
+    projectSettings->readFromSettings( m_pSettings, projectPath);
 }
 
 //----------------------------------------------------------------------------
 
 void CvsConfig::writeProjectSettings( QString projectPath) {
-
-   unsigned int i = 0;
-   QStringList oldSettings = m_pSettings->subkeyList( projectPath);
-  
-   QStringList projectList;
-   projectSettings->getProjects( projectList);
-  
-   for( i = 0; i < projectList.count(); i++) {
     
-      QStringList::iterator it = oldSettings.find(projectList[i]);
-      if (it != oldSettings.end()) {
-	 oldSettings.remove(it);
-      }
+    unsigned int i = 0;
+    QStringList oldSettings = m_pSettings->subkeyList( projectPath);
     
-   }
-   for( i = 0; i < oldSettings.count(); i++) {
-      QString key = QString(projectPath)+"/"+oldSettings[i];
-      removeProjectSettings( key);
-   }
-   projectSettings->writeToSettings(m_pSettings,projectPath);
-
-   //remove old project settings model list
-   m_pSettings->removeEntry("/lincvs/Workbench/projectList");
-   m_pSettings->removeEntry("/lincvs/Workbench/projectDisabledList");
-
-   //     projectSettings->test();
-
+    QStringList projectList;
+    projectSettings->getProjects( projectList);
+    
+    for( i = 0; i < projectList.count(); i++) {
+        
+        QStringList::iterator it = oldSettings.find(projectList[i]);
+        if (it != oldSettings.end()) {
+            oldSettings.remove(it);
+        }
+        
+    }
+    for( i = 0; i < oldSettings.count(); i++) {
+        QString key = QString(projectPath)+"/"+oldSettings[i];
+        removeProjectSettings( key);
+    }
+    projectSettings->writeToSettings(m_pSettings,projectPath);
+    
+    //remove old project settings model list
+    m_pSettings->removeEntry("/lincvs/Workbench/projectList");
+    m_pSettings->removeEntry("/lincvs/Workbench/projectDisabledList");
+    
+    //     projectSettings->test();
 }
 
 //----------------------------------------------------------------------------
@@ -748,7 +753,18 @@ void CvsConfig::readExtApps()
 {
    QString tmpExtApp;
    int pos;
+
+   ExtApps::g_sshKeyFiles = getSshKeyList();
     
+   tmpExtApp = sshAgent(); pos = tmpExtApp.find("\n");
+   if (pos >= 0) {
+      ExtApps::g_sshAgent.path = tmpExtApp.left(pos).stripWhiteSpace();
+      ExtApps::g_sshAgent.options = tmpExtApp.right(tmpExtApp.length() - pos).stripWhiteSpace();
+   } else {
+      ExtApps::g_sshAgent.path = tmpExtApp.stripWhiteSpace();
+      ExtApps::g_sshAgent.options = QString::null;
+   }
+      
    tmpExtApp = localShell(); pos = tmpExtApp.find("\n");
    if (pos >= 0) {
       ExtApps::g_localShell.path = tmpExtApp.left(pos).stripWhiteSpace();
@@ -757,7 +773,6 @@ void CvsConfig::readExtApps()
       ExtApps::g_localShell.path = tmpExtApp.stripWhiteSpace();
       ExtApps::g_localShell.options = QString::null;
    }
-      
    tmpExtApp = localBrowser(); pos = tmpExtApp.find("\n");
    if (pos >= 0) {
       ExtApps::g_localBrowser.path = tmpExtApp.left(pos).stripWhiteSpace();
@@ -801,6 +816,8 @@ void CvsConfig::readExtApps()
 
 void CvsConfig::writeExtApps()
 {
+   setSshKeyList(ExtApps::g_sshKeyFiles);
+   setSshAgent(ExtApps::g_sshAgent.path + "\n" + ExtApps::g_sshAgent.options);
    setLocalShell(ExtApps::g_localShell.path + "\n" + ExtApps::g_localShell.options);
    setLocalBrowser(ExtApps::g_localBrowser.path + "\n" + ExtApps::g_localBrowser.options);
    setRemoteBrowser(ExtApps::g_remoteBrowser.path + "\n" + ExtApps::g_remoteBrowser.options);
