@@ -1,6 +1,4 @@
 /****************************************************************************
- **
- ** $Id: cvsconfig.h,v 1.56 2005/01/10 17:19:08 frank Exp $
  **
  ** Copyright (C) 2001-2004 Tilo Riemer <riemer@lincvs.org>,
  **                         Frank Hemer <frank@hemer.org>,
@@ -161,6 +159,8 @@ class CvsConfig
    static const char HistoryPeriod[];
    static const char Quiet[];
 
+   static const char SshKeyList[];
+   static const char SshAgent[];
    static const char RemoteBrowser[];
    static const char LocalBrowser[];
    static const char CVSRsh[];
@@ -217,6 +217,7 @@ class CvsConfig
    
    //defaults
    static const char defCvsVersion[];
+   static const char defSshAgent[];
    static const char defRemoteBrowser[];
    static const char defLocalBrowser[];
    static const char defCvsRsh[];
@@ -414,6 +415,19 @@ class CvsConfig
    void setUseExtDiff(bool useIt) {
       m_pSettings->writeEntry(UseExternalDiff, useIt);
    }
+   QStringList getSshKeyList() {
+      QStringList list = m_pSettings->readListEntry(SshKeyList);
+      return list;
+   }
+   void setSshKeyList(QStringList list) {
+      m_pSettings->writeEntry(SshKeyList,list);
+   }
+   QString sshAgent() {
+      return m_pSettings->readEntry(SshAgent, defSshAgent);
+   }
+   void setSshAgent(const QString& prog) {
+      m_pSettings->writeEntry(SshAgent, prog);
+   }
    QString extDiffProgram() {
       return m_pSettings->readEntry(ExtDiffProgram, "");
    }
