@@ -84,6 +84,7 @@
 #include <qdatetimeedit.h>
 #include <qtimer.h>
 #include <qwhatsthis.h>
+#include <assert.h>
 
 #include "globals.h"
 #include "CheckoutDialogImpl.h"
@@ -104,26 +105,29 @@ CheckoutDialogImpl::CheckoutDialogImpl( QString dlgCaption,
       const char* name,
       bool modal,
       WFlags fl )
-//   : CheckoutDialog( LookAndFeel::g_b0AsParent ? 0 : parent, name, modal, fl ),
-  : CheckoutDialog( modal ? parent : (LookAndFeel::g_b0AsParent ? 0 : parent),
-		    name, modal, fl ),
-     m_parent(parent),
-     m_defBrowseModButtonName(BrowseModulesButton->name()),
-     m_defBrowseModButtonText(BrowseModulesButton->text()),
-     m_ProfileList(*ProfileList),
-     m_UserList(*UserList),
-     m_ServerList(*ServerList),
-     m_RepositoryList(*RepositoryList),
-     m_WorkdirList(*WorkdirList),
-     m_ModuleList(*ModuleList),
-     m_CheckoutAsList(*CheckoutAsList),
-     m_running(false)
+   : CheckoutDialog( modal ? parent : (LookAndFeel::g_b0AsParent ? 0 : parent),
+	 name, modal, fl ),
+	  m_parent(parent),
+	  m_defBrowseModButtonName(BrowseModulesButton->name()),
+	  m_defBrowseModButtonText(BrowseModulesButton->text()),
+	  m_ProfileList(*ProfileList),
+	  m_UserList(*UserList),
+	  m_ServerList(*ServerList),
+	  m_RepositoryList(*RepositoryList),
+	  m_WorkdirList(*WorkdirList),
+	  m_ModuleList(*ModuleList),
+	  m_CheckoutAsList(*CheckoutAsList),
+	  m_running(false)
 {
    setCaption(dlgCaption);
    m_defaultProfile = defaultProfile;
 
    m_pWhatsThis->setIconSet(whatsThisIconSet);
-   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
   
    //for now this emulates the enum used in ProfilesDialogImpl
    //this should be replaced by a common usage
@@ -202,6 +206,7 @@ CheckoutDialogImpl::CheckoutDialogImpl( QString dlgCaption,
    }
 
    resetSize();
+   connect(this,SIGNAL(showWarning(const QString&,const QString&)),parent,SLOT(showWarning(const QString&,const QString&)));
 }
 
 /*  
@@ -353,70 +358,67 @@ void CheckoutDialogImpl::browseModulesClicked() {
 	 mBrowser->setCaption(tr("CVS Module Browser"));
 	 mBrowser->exec();
       } else {
-	 BrowseModulesButton->setName("stop action");
-	 BrowseModulesButton->setText(tr("Stop"));
-	 callCvs("checkout -p -n CVSROOT/modules",CVS_MBROWSEMODULES_CMD);
+	 QString connMethod;
+	 if( (*m_AccessDict.find(m_AccessBox->currentText()))==PSERVER) {
+	    connMethod = "pserver";
+	 } else if((*m_AccessDict.find(m_AccessBox->currentText()))==RSH) {
+	    if(m_ExternalRsh->isChecked()) {
+	       connMethod = "ext";
+	    } else {
+	       connMethod = "server";
+	    }
+	 }
+	 
+	 QString dir = "";
+	 QString server = m_ServerBox->currentText();
+	 if (server.find(':') == -1) server += ":";
+	 m_TmpBrowseModulesRoot =
+	    ":"+connMethod+
+	    ":"+m_UserBox->currentText()+
+	    "@"+server+
+	    m_RepositoryBox->currentText();
+	 
+	 if (validateCVSROOT(m_TmpBrowseModulesRoot) == 0) {
+
+	    int sshAccess = getSshPreset();
+	    //check ssh access settings
+	    bUseSsh = false;
+	    bUseSshAgent = false;
+	    bUseSshAgentVars = false;
+	    switch( sshAccess) {
+	       case USESSH: {
+		  bUseSsh = true;
+		  break;
+	       }
+	       case USESSHAGENT: {
+		  bUseSshAgent = true;
+		  break;
+	       }
+	       case USESSHAGENTVARS: {
+		  bUseSshAgentVars = true;
+		  break;
+	       }
+	    }
+	    
+	    m_ModuleBrowser = new ModuleBrowserImpl(*(m_pWhatsThis->iconSet()),
+		  NULL,
+		  m_TmpBrowseModulesRoot,
+		  m_parent,
+		  this,
+		  "Browse Modules",
+		  true,
+		  LookAndFeel::g_modalF | WDestructiveClose);
+	    
+	    connect(m_ModuleBrowser,SIGNAL(OkClicked()),this,SLOT(getAndSetModule()));
+	    m_ModuleBrowser->start();
+
+	 } else {
+	    emit showWarning(tr("Warning"),tr("Cannot connect, invalid CVSROOT:")+"\n"+m_TmpBrowseModulesRoot);
+	 }
       }
    }
 }
 
-//unfortunatelly the status cmd requires a sandbox, so it's of no use here
-void CheckoutDialogImpl::updateProjectTagList() {
-   m_TagList.clear();
-   QString command = m_BrowseModules->currentText();
-   if (command.isEmpty()) return;
-   command = "status -v " + command;
-   callCvs(command,CVS_GET_TAG_INFO_PROJECT_CMD);
-}
-
-void CheckoutDialogImpl::callCvs(QString strCmd, int cmd) {
-
-   QString connMethod;
-   if( (*m_AccessDict.find(m_AccessBox->currentText()))==PSERVER) {
-      connMethod = "pserver";
-   } else if((*m_AccessDict.find(m_AccessBox->currentText()))==RSH) {
-      if(m_ExternalRsh->isChecked()) {
-	 connMethod = "ext";
-      } else {
-	 connMethod = "server";
-      }
-   }
-  
-   QString dir = "";
-   QString server = m_ServerBox->currentText();
-   if (server.find(':') == -1) server += ":";
-   m_TmpBrowseModulesRoot =
-      ":"+connMethod+
-      ":"+m_UserBox->currentText()+
-      "@"+server+
-      m_RepositoryBox->currentText();
-  
-   int sshAccess = getSshPreset();
-   //check ssh access settings
-   bUseSsh = false;
-   bUseSshAgent = false;
-   bUseSshAgentVars = false;
-   switch( sshAccess) {
-      case USESSH: {
-	 bUseSsh = true;
-	 break;
-      }
-      case USESSHAGENT: {
-	 bUseSshAgent = true;
-	 break;
-      }
-      case USESSHAGENTVARS: {
-	 bUseSshAgentVars = true;
-	 break;
-      }
-   }
-  
-   QString topModule = QString::null;
-   callInteractive( topModule, dir, m_TmpBrowseModulesRoot,
-	 strCmd, cmd, ExtApps::g_cvsRsh.path, //additional options of cvsRsh not supported yet
-	 false);
-}
-
 void CheckoutDialogImpl::resetSize() {
    QTimer::singleShot(0,this,SLOT(reduceHeight()));
 }
@@ -432,6 +434,17 @@ QSize CheckoutDialogImpl::sizeHint () const {
 }
 
 void CheckoutDialogImpl::accept() {
+
+   if (m_RepositoryBox->currentText().isEmpty()) {
+      emit showWarning(tr("Warning"), tr("You have to enter a repository"));
+      return;
+   } else if (m_ImportDir->currentText().isEmpty()) {
+      emit showWarning(tr("Warning"), tr("You have to enter a target dir"));
+      return;
+   } else if (m_BrowseModules->currentText().isEmpty()) {
+      emit showWarning(tr("Warning"), tr("You have to enter a module name"));
+      return;
+   }
    CheckoutDialog::accept();
 }
 
@@ -514,6 +527,7 @@ void CheckoutDialogImpl::getAndSetModule() {
    if (m_CheckoutAs->currentText().isEmpty()) {
       m_CheckoutAs->setCurrentText(m_checkoutAsDOption);
    }
+   m_ModuleBrowser = NULL;
 }
 
 void CheckoutDialogImpl::insertModule(const QString& module) {
@@ -537,6 +551,7 @@ void CheckoutDialogImpl::setEnabled(bool state) {
    m_BrowseModules->setEnabled(state);
    m_CheckoutAs->setEnabled(state);
    BrowseDirButton->setEnabled(state);
+   BrowseModulesButton->setEnabled(state);
 }
 
 void CheckoutDialogImpl::cvsCallStarted() {
@@ -551,134 +566,12 @@ void CheckoutDialogImpl::cvsCallFinished() {
    m_running = false;
 }
 
-void CheckoutDialogImpl::afterCall( int cmd, CvsBuffer* output, bool failed) {
+void CheckoutDialogImpl::afterCall( int cmd, CvsBuffer *, bool) {
    cvsCallFinished();
 
    switch (cmd) {
-      case CVS_GET_TAG_INFO_PROJECT_CMD: {
-
-	 if (failed) return;
-
-	 QString line;
-	 int pos = 0;
-	 unsigned int len = (*output).numLines();
-	 unsigned int skipLines = outputLineOffset;
-	 for (unsigned int i = skipLines; i<len;++i) {//only two lines if no CVSROOT/modules file
-	    line = (*output).textLine(i);
-	    if (pos == 0) {
-	       if (line.find("Existing Tags:") > -1) pos = 1;
-	    }
-	    else if ( (line.find("No Tags Exist") > -1)
-		  || (line.startsWith("cvs "))
-		  || (line.startsWith("===================================================================")) ) {
-	       pos = 0;
-	    } else {
-	       QRegExp rx( "(\\b\\S+\\b)(?:\\s*\\()(\\w+):" );
-	       rx.search(line);
-	       QString txt;
-	       if (rx.cap(2).startsWith("branch")) {
-		  txt = "B: "+rx.cap(1);
-	       } else if (rx.cap(2).startsWith("revision")) {
-		  txt = "T: "+rx.cap(1);
-	       } else {
-		  qDebug("unknown line on GET_TAG_INFO: "+line);
-		  continue;
-	       }
-	       if (m_TagList.find(txt) == m_TagList.end()) {
-		  m_TagList.append(txt);
-	       }
-	    }
-	 }
-	 emit tagListFetched();
-	 return;
-      }
-      case CVS_MBROWSEMODULES_CMD: {
-	 if (failed) {
-	    BrowseModulesButton->setName(m_defBrowseModButtonName);
-	    BrowseModulesButton->setText(m_defBrowseModButtonText);
-	    return;
-	 }
-	 m_checkoutAsDOption = "";
-	 bool fileOk = false;
-	 QString line;
-	 unsigned int len = (*output).numLines();
-	 unsigned int skipLines = outputLineOffset + 6;
-	 for (unsigned int i = skipLines; i<len;i++) {//only two lines if no CVSROOT/modules file
-	    line = (*output).textLine(i);
-	    if ( (line.at(0)!='#') && ( !(line.isEmpty()) ) ) {
-	       fileOk = true;
-	       break;
-	    }
-	 }
-	 if (!fileOk) {
-	    int sshAccess = getSshPreset();
-	    //check ssh access settings
-	    bUseSsh = false;
-	    bUseSshAgent = false;
-	    bUseSshAgentVars = false;
-	    switch( sshAccess) {
-	       case USESSH: {
-		  bUseSsh = true;
-		  break;
-	       }
-	       case USESSHAGENT: {
-		  bUseSshAgent = true;
-		  break;
-	       }
-	       case USESSHAGENTVARS: {
-		  bUseSshAgentVars = true;
-		  break;
-	       }
-	    }
-	    QString dir = "";
-	    QString files = "history -xAMR -a -l";
-	    QString topModule = QString::null;
-	    callInteractive( topModule, dir, m_TmpBrowseModulesRoot,
-		  files, CVS_HBROWSEMODULES_CMD,
-		  ExtApps::g_cvsRsh.path,  //additional options of cvsRsh not supported yet
-		  false);
-	    return;
-	 } else {
-	    BrowseModulesButton->setName(m_defBrowseModButtonName);
-	    BrowseModulesButton->setText(m_defBrowseModButtonText);
-	    m_ModuleBrowser = new ModuleBrowserImpl(*(m_pWhatsThis->iconSet()),
-		  NULL,
-		  m_TmpBrowseModulesRoot,
-		  m_parent,
-		  this,
-		  "Browse Modules",
-		  true,
-		  LookAndFeel::g_modalF | WDestructiveClose);
-	
-	    connect(m_ModuleBrowser,SIGNAL(OkClicked()),this,SLOT(getAndSetModule()));
-	    m_ModuleBrowser->parseModules (output);
-	    m_ModuleBrowser->show();
-	 }
-	 break;
-      }
-      case CVS_HBROWSEMODULES_CMD: {
-	 if (failed) {
-	    BrowseModulesButton->setName(m_defBrowseModButtonName);
-	    BrowseModulesButton->setText(m_defBrowseModButtonText);
-	    return;
-	 }
-	 BrowseModulesButton->setName(m_defBrowseModButtonName);
-	 BrowseModulesButton->setText(m_defBrowseModButtonText);
-	 m_checkoutAsDOption = "";
-	 m_ModuleBrowser = new ModuleBrowserImpl(*(m_pWhatsThis->iconSet()),
-	       NULL,
-	       m_TmpBrowseModulesRoot,
-	       m_parent,
-	       this,
-	       "Browse Modules",
-	       true,
-	       LookAndFeel::g_modalF | WDestructiveClose);
-      
-	 connect(m_ModuleBrowser,SIGNAL(OkClicked()),this,SLOT(getAndSetModule()));
-	 m_ModuleBrowser->parseHistory (output);
-	 m_ModuleBrowser->show();
-	 break;
-      }
+      default:
+	 assert(false);
    }
 }
 
