@@ -1,6 +1,4 @@
 /****************************************************************************
- **
- ** $Id: CommandInterface.h,v 1.35 2004/10/27 17:00:05 frank Exp $
  **
  ** Copyright (C) 2001-2004 The LinCVS development team.
  **    Tilo Riemer <riemer@lincvs.org>
@@ -102,51 +100,53 @@ static const int CVS_Y_N                           =  0;
 static const int CVS_RELEASE_CMD                   =  1;
 static const int CVS_RELEASE_D_CMD                 =  2;
 static const int CVS_UNEDIT_CMD                    =  3;
-static const int CVS_STATUS_CMD                    =  4;
-static const int CVS_STATUS_FILES_CMD              =  5;
-static const int CVS_UPDATE_DIR_CMD                =  6;
-static const int CVS_UPDATE_FILES_CMD              =  7;
-static const int CVS_ANNOTATE_GREP_LINE_CMD        =  8;
-static const int CVS_ANNOTATE_GREP_LINES_CMD       =  9;
-static const int CVS_COMMIT_CMD                    = 10;
-static const int CVS_HISTORY_CMD                   = 11;
-static const int CVS_DIFF_CMD                      = 12;
-static const int CVS_DIFF_SBS_CMD                  = 13;
-static const int CVS_DIFF_EXT_CMD                  = 14;
-static const int CVS_ANNOTATE_CMD                  = 15;
-static const int CVS_CHECKOUT_CMD                  = 16;
-static const int CVS_IMPORT_CMD                    = 17;
-static const int CVS_TAG_CMD                       = 18;
-static const int CVS_LOG_DIR_CMD                   = 19;
-static const int CVS_RENAME_CMD                    = 20;
-static const int CVS_REMOVE_CMD                    = 21;
-static const int CVS_REMOVE_AND_RENAME_CMD         = 22;
-static const int CVS_ADD_CMD                       = 23;
-static const int CVS_QUERY_UPDATE_CMD              = 24;
-static const int CVS_QUERY_UPDATE_ALL_CMD          = 25;
-static const int CVS_EDIT_REVISION_CMD             = 26;
-static const int CVS_MERGE_REV_INTO_CMD            = 27;
-static const int CVS_RESURRECT_CMD                 = 28;
-static const int CVS_SHOW_EDITORS_CMD              = 29;
-static const int CVS_SHOW_WATCHERS_CMD             = 30;
-static const int CVS_MERGE_DIR_CMD                 = 31;
-static const int CVS_MERGE_FILES_CMD               = 32;
-static const int CVS_LOCKFILE_CMD                  = 33;
-static const int CVS_UNLOCKFILE_CMD                = 34;
-static const int CVS_HBROWSEMODULES_CMD            = 35;
-static const int CVS_MBROWSEMODULES_CMD            = 36;
-static const int CVS_EXPORT_CMD                    = 37;
-static const int CVS_REMOVEDIR_CMD                 = 38;
-static const int CVS_AUTOUPDATE_DIR_CMD            = 39;
-static const int CVS_AUTOUPDATE_DIR_NO_PRUNE_CMD   = 40;
-static const int CVS_CHECKOUT_NO_PRUNE_CMD         = 41;
-static const int CVS_MERGE_DIR_NO_PRUNE_CMD        = 42;
-static const int CVS_UPDATE_VIRTUAL_DIR_CMD        = 43;
-static const int CVS_MOVE_FILES_CMD                = 44;
-static const int CVS_REVERT_DIR_CMD                = 45;
-static const int CVS_REVERT_FILES_CMD              = 46;
-static const int CVS_GET_TAG_INFO_PROJECT_CMD      = 47;
-static const int CVS_GET_TAG_INFO_FILES_CMD        = 48;
+static const int CVS_EDIT_CMD                      =  4;
+static const int CVS_STATUS_CMD                    =  5;
+static const int CVS_STATUS_FILES_CMD              =  6;
+static const int CVS_UPDATE_DIR_CMD                =  7;
+static const int CVS_UPDATE_FILES_CMD              =  8;
+static const int CVS_ANNOTATE_GREP_LINE_CMD        =  9;
+static const int CVS_ANNOTATE_GREP_LINES_CMD       = 10;
+static const int CVS_COMMIT_CMD                    = 11;
+static const int CVS_HISTORY_CMD                   = 12;
+static const int CVS_DIFF_CMD                      = 13;
+static const int CVS_DIFF_SBS_CMD                  = 14;
+static const int CVS_DIFF_EXT_CMD                  = 15;
+static const int CVS_ANNOTATE_CMD                  = 16;
+static const int CVS_CHECKOUT_CMD                  = 17;
+static const int CVS_IMPORT_CMD                    = 18;
+static const int CVS_TAG_CMD                       = 19;
+static const int CVS_LOG_DIR_CMD                   = 20;
+static const int CVS_RENAME_CMD                    = 21;
+static const int CVS_REMOVE_CMD                    = 22;
+static const int CVS_REMOVE_AND_RENAME_CMD         = 23;
+static const int CVS_ADD_CMD                       = 24;
+static const int CVS_QUERY_UPDATE_CMD              = 25;
+static const int CVS_QUERY_UPDATE_ALL_CMD          = 26;
+static const int CVS_EDIT_REVISION_CMD             = 27;
+static const int CVS_MERGE_REV_INTO_CMD            = 28;
+static const int CVS_RESURRECT_CMD                 = 29;
+static const int CVS_SHOW_EDITORS_CMD              = 30;
+static const int CVS_SHOW_WATCHERS_CMD             = 31;
+static const int CVS_MERGE_DIR_CMD                 = 32;
+static const int CVS_MERGE_FILES_CMD               = 33;
+static const int CVS_LOCKFILE_CMD                  = 34;
+static const int CVS_UNLOCKFILE_CMD                = 35;
+static const int CVS_HBROWSEMODULES_CMD            = 36;
+static const int CVS_MBROWSEMODULES_CMD            = 37;
+static const int CVS_EXPORT_CMD                    = 38;
+static const int CVS_REMOVEDIR_CMD                 = 39;
+static const int CVS_AUTOUPDATE_DIR_CMD            = 40;
+static const int CVS_AUTOUPDATE_DIR_NO_PRUNE_CMD   = 41;
+static const int CVS_CHECKOUT_NO_PRUNE_CMD         = 42;
+static const int CVS_MERGE_DIR_NO_PRUNE_CMD        = 43;
+static const int CVS_UPDATE_VIRTUAL_DIR_CMD        = 44;
+static const int CVS_MOVE_FILES_CMD                = 45;
+static const int CVS_REVERT_DIR_CMD                = 46;
+static const int CVS_REVERT_FILES_CMD              = 47;
+static const int CVS_GET_TAG_INFO_PROJECT_CMD      = 48;
+static const int CVS_GET_TAG_INFO_FILES_CMD        = 49;
+static const int CVS_RLSBROWSEMODULES_CMD          = 50;
 
 class CvsControl;
 
