@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: CustomizeDialogImpl.cpp,v 1.13 2004/12/03 00:25:46 tilo Exp $
-**
 ** Copyright (C) 2001-2004 Frank Hemer.
 **
 **
@@ -89,7 +87,11 @@ CustomizeDialogImpl::CustomizeDialogImpl(QVector<MenuItem> *choice, QVector<Menu
 		     name, modal, f)
 {
   m_pWhatsThis->setIconSet(whatsThisIconSet);
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
   p_preset = preset;
   m_choice = QVector<MenuItem> (0);
@@ -105,8 +107,11 @@ CustomizeDialogImpl::CustomizeDialogImpl(QVector<MenuItem> *choice, QVector<Menu
   //fill selectBox
   for(i = 0; i<(int)p_preset->count(); i++ ) {
     QString txt = (*p_preset)[i]->caption();
-    if ( (*p_preset)[i]->getFirstChild()) txt += tr(" (+submenu)");
-     selectedBox->insertItem(txt);
+    if ( (*p_preset)[i]->getFirstChild()) {
+      txt += " ";
+      txt += tr("(submenu)");
+    }
+    selectedBox->insertItem(txt);
   }
   //find and fill local choice (what is left and not in menu yet)
   m_choice.resize(choice->count());
@@ -126,8 +131,11 @@ CustomizeDialogImpl::CustomizeDialogImpl(QVector<MenuItem> *choice, QVector<Menu
   //fill choiceBox
   for(i = 0; i<(int)m_choice.count(); i++ ) {
     QString txt = m_choice[i]->caption();
-    if (m_choice[i]->getFirstChild()) txt += tr(" (+submenu)");
-     choiceBox->insertItem(txt);
+    if (m_choice[i]->getFirstChild()) {
+      txt += " ";
+      txt += tr("(submenu)");
+    }
+    choiceBox->insertItem(txt);
   }
 }
 
@@ -143,7 +151,10 @@ void CustomizeDialogImpl::add() {
     for (int i = m_preset.size()-1; i>to; i--) m_preset.insert(i,m_preset[i-1]);
     m_preset.insert(to,(m_choice[from]));
     QString txt = m_preset[to]->caption();
-    if (m_preset[to]->getFirstChild()) txt += tr(" (+submenu)");
+    if (m_preset[to]->getFirstChild()) {
+      txt += " ";
+      txt += tr("(submenu)");
+    }
     selectedBox->insertItem(txt,to);
     if (needsRemove(m_choice[from])) {
       for (int i = from; i<(int)m_choice.count()-1;i++) m_choice.insert(i,m_choice[i+1]);
@@ -168,7 +179,10 @@ void CustomizeDialogImpl::remove() {
       for (int i = m_choice.size()-1; i>pos; i--) m_choice.insert(i,m_choice[i-1]);
       m_choice.insert(pos,(m_preset[from]));
       txt = m_preset[from]->caption();
-      if (m_preset[from]->getFirstChild()) txt += tr(" (+submenu)");
+      if (m_preset[from]->getFirstChild()) {
+	txt += " ";
+	txt += tr("(submenu)");
+      }
       choiceBox->insertItem(txt,pos);
     }
     for (int i = from; i<(int)m_preset.size()-1; i++) m_preset.insert(i,m_preset[i+1]);
@@ -188,7 +202,10 @@ void CustomizeDialogImpl::up() {
     m_preset.insert(pos,tmp);
     selectedBox->removeItem(pos);
     QString txt = m_preset[pos-1]->caption();
-    if (m_preset[pos-1]->getFirstChild()) txt += tr(" (+submenu)");
+    if (m_preset[pos-1]->getFirstChild()) {
+	txt += " ";
+	txt += tr("(submenu)");
+    }
     selectedBox->insertItem(txt,pos-1);
     selectedBox->setSelected(pos-1,true);
     selectedBox->ensureCurrentVisible();
@@ -203,7 +220,10 @@ void CustomizeDialogImpl::down() {
     m_preset.insert(pos,tmp);
     selectedBox->removeItem(pos);
     QString txt = m_preset[pos+1]->caption();
-    if (m_preset[pos+1]->getFirstChild()) txt += tr(" (+submenu)");
+    if (m_preset[pos+1]->getFirstChild()) {
+	txt += " ";
+	txt += tr("(submenu)");
+    }
     selectedBox->insertItem(txt,pos+1);
     selectedBox->setSelected(pos+1,true);
     selectedBox->ensureCurrentVisible();
