@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: CustomizeShortcutsDialogImpl.cpp,v 1.20 2004/12/03 00:25:46 tilo Exp $
-**
 ** Copyright (C) 1999-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
 **    Falk Brettschneider <gigafalk@yahoo.com>
@@ -123,7 +121,11 @@ CustomizeShortcutsDialogImpl::CustomizeShortcutsDialogImpl(const QIconSet &whats
     m_parent(parent) 
 {
   m_pWhatsThis->setIconSet(whatsThisIconSet);
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
   keyMap.clear();
   RadioButtonGroup->setEnabled(FALSE);
