@@ -1,17 +1,7 @@
 /****************************************************************************
  **
- ** $Id: CvsDirectory.cpp,v 1.43.2.2 2005/01/20 02:25:26 frank Exp $
- **
- ** Copyright (C) 1999-2004 The LinCVS development team.
- **    Tilo Riemer <riemer@lincvs.org>
- **    Falk Brettschneider <gigafalk@yahoo.com>
- **    Frank Hemer <frank@hemer.org>
- **    Wim Delvaux <wim.delvaux@chello.be>
- **    Jose Hernandez <joseh@tesco.net>
- **    Helmut Koll <HelmutKoll@web.de>
- **    Tom Mishima <tmishima@mail.at-m.or.jp>
- **    Joerg Preiss <auba@auba.de>
- **    Sven Trogisch <trogisch@iapp.de>
+ ** Copyright (C) 1999-2005 Frank Hemer <frank@hemer.org>
+ **                         Tilo Riemer <riemer@lincvs.org>
  **
  **
  **----------------------------------------------------------------------------
@@ -261,7 +251,7 @@ bool CvsDirectory::loginOk(CCvsOutput *pMessages, bool showMessage)
       if (showMessage) {
 	 QString cap = LC_APPNAME;
 	 cap += " - " + QObject::tr("Information");
-	 QMessageBox::information(qApp->mainWidget(), cap, QObject::tr("Login successfully."), 0);
+	 QMessageBox::information(qApp->mainWidget(), cap, QObject::tr("Login successful."), 0);
       }
 
       return true;
@@ -363,6 +353,8 @@ bool CvsDirectory::checkDirForControl( ) {
    QFile f;
    QString line;
    
+   QString logMsg;
+
    //read Root
    f.setName(path + "CVS/Root");
    if(f.open(IO_ReadOnly)) {//file is readable
@@ -379,18 +371,31 @@ bool CvsDirectory::checkDirForControl( ) {
 		  m_host,
 		  m_port,
 		  m_rootDir)) {
+         Debug::g_pLog->log (Debug::LL_GOSSIP_MONGER, "extractCVSROOT failed");
 	 return false;
       }
 
       if ((m_connectMethod == "local")
-	    || (m_connectMethod == "fork"))
-	 { //local
-	    m_userName = getenv("USER");
-	    m_host = "localhost";
-	    m_connectMethod = "local";
-	 }
+	    || (m_connectMethod == "fork")) { //local
+	 m_userName = getenv("USER");
+	 m_host = "localhost";
+	 m_connectMethod = "local";
+      }
+
+      if (Debug::g_logLevel == Debug::LL_GOSSIP_MONGER) {
+         logMsg += "extracting CVS/Root in: "+m_fullName+"\n";
+         logMsg += "\tconnectMethod: "+m_connectMethod+"\n";
+         logMsg += "\tuserName: "+m_userName+"\n";
+         if (!m_passwd.isEmpty ()) logMsg += "\tpassword set: xxxxx\n";
+         logMsg += "\thost: "+m_host+"\n";
+         logMsg += "\tport: "+QString::number (m_port)+"\n";
+         logMsg += "\trootDir: "+m_rootDir+"\n";
+      }
+
+   } else {
+      Debug::g_pLog->log (Debug::LL_THE_OLD_MAN_AND_THE_SEA, m_fullName+": cannot read CVS/Root");
+      return false;
    }
-   else return false;
 
    //read Repository
    f.setName(path + "CVS/Repository");
@@ -398,8 +403,19 @@ bool CvsDirectory::checkDirForControl( ) {
       QTextStream textStream(&f); 
       m_repository = textStream.readLine().stripWhiteSpace();
       f.close();
+
+      if (Debug::g_logLevel == Debug::LL_GOSSIP_MONGER) {
+         logMsg += "extracting CVS/Repository\n";
+         logMsg += "\trepository: "+m_repository+"\n";
+      }
+
+   } else {
+      if (Debug::g_logLevel == Debug::LL_THE_OLD_MAN_AND_THE_SEA) {
+         logMsg += m_fullName+": cannot read CVS/Repository";
+         Debug::g_pLog->log (Debug::LL_THE_OLD_MAN_AND_THE_SEA, logMsg);
+      }
+      return false;
    }
-   else return false;
 
    //workaround for old cvs version
    if(m_repository.find(m_rootDir) == 0){//old cvs version detected
@@ -416,22 +432,10 @@ bool CvsDirectory::checkDirForControl( ) {
 	 else if (m_repository != p->repository()+"/"+name) {//maybe sub project
 	    //test for existence in parent entries file
 	    addSubProject = true;
-	    f.setName(parent()->fullName() + "/CVS/Entries");
-	    if(f.open(IO_ReadOnly)) {//file is readable
-	       QTextStream textStream(&f); 
-	       textStream.setCodec(I18n::g_pTextDecoder->pTextCodecPool()->pCodecForName(I18n::g_nameOfDecoder));
-	       while(!textStream.eof()) {
-		  line = textStream.readLine();
-		  if(line.at(0) == 'D') {//entry is a directory
-		     line = line.mid(2);
-		     line.truncate(line.find("/"));
-		     if (line == name) {//no sub project
-			addSubProject = false;
-			break;
-		     }
-		  }
-	       }
-	       f.close();
+	    QStringList dirList = parent()->getControledSubdirs();
+	    QStringList::Iterator iterator;
+	    if ( (iterator = dirList.find(name)) != dirList.end() ) {
+	       addSubProject = false;
 	    }
 	 }
       } else {
@@ -451,11 +455,104 @@ bool CvsDirectory::checkDirForControl( ) {
       }
    }
 
+   Debug::g_pLog->log (Debug::LL_GOSSIP_MONGER, logMsg);
    return true;
 }
 
 //---------------------------------------------------------------------------
 
+QStringList CvsDirectory::getControledSubdirs() {
+   QStringList list;
+   QStringList::Iterator iterator;
+   QString line;
+   QTextStream textStream; 
+   textStream.setCodec(I18n::g_pTextDecoder->pTextCodecPool()->pCodecForName(I18n::g_nameOfDecoder));
+   QFile f(m_fullName+"/CVS/Entries");
+   if (f.open(IO_ReadOnly)) {
+      textStream.setDevice(&f);
+      while (!textStream.eof()) {
+	 line = textStream.readLine();
+	 if (line.at(0) == 'D') {//entry is a directory
+	    list.append(line.section("/",1,1));
+	 }
+      }
+      f.close();
+      f.setName(m_fullName+"/CVS/Entries.Log");
+      if (f.open(IO_ReadOnly)) {
+	 textStream.setDevice(&f);
+	 while (!textStream.eof()) {
+	    line = textStream.readLine();
+	    if (line.at(2) != 'D') continue;
+	    if (line.at(0) == 'A') {//added
+	       line = line.section('/',1,1);
+	       if (list.findIndex(line) == -1) list.append(line);
+	    } else if (line.at(0) == 'R') {//removed
+	       line = line.section('/',1,1);
+	       iterator = list.find(line);
+	       if (iterator != list.end()) {
+		  list.remove(iterator);
+	       }
+	    }
+	 }
+	 f.close();
+      }
+   }
+   return list;
+}
+
+//---------------------------------------------------------------------------
+
+DirBase * CvsDirectory::searchDirOfPath (QString path, bool findVirtual /* = false */) {
+   if (!findVirtual && m_virtual) {
+      return NULL;
+   }
+   if (path.compare (m_fullName) == 0) {
+      return this;   //its my path :-)
+   }
+  
+   if (path.find (m_fullName+"/") == 0) {//is subdir
+      CvsDirectory * myChild = firstChild();
+      CvsDirectory * result;
+      while (myChild) {
+	 if ( (result = dyncast_cvsdir (myChild->searchDirOfPath (path, findVirtual))) ) {
+	    return result;
+	 }
+	 else {
+	    myChild = myChild->nextSibling ();
+	 }
+      }
+   }
+   return NULL;
+}
+
+//----------------------------------------------------------------------------
+
+//return the deepest valid (not disabled, not virtual) dir in hierarchy
+DirBase * CvsDirectory::searchLastValidDirOfPath (QString path) {
+   if (m_disabled || m_virtual) {
+      return NULL;
+   }
+   if (path.compare(m_fullName) == 0) {
+      return this;   //its my path :-)
+   }
+   if (path.find(m_fullName+"/") == 0) {//is subdir
+      CvsDirectory * myChild = firstChild();
+      CvsDirectory * result;
+      while (myChild) {
+	 if ( (result = dyncast_cvsdir (myChild->searchLastValidDirOfPath (path))) ) {
+	    return result;
+	 }
+	 else {
+	    myChild = myChild->nextSibling ();
+	 }
+      }
+      return this;
+   }
+   return NULL;
+}
+
+//---------------------------------------------------------------------------
+
 //recursive check for modifications, only detected by a timestamp
 //change of the dir or its CVS/Entries file
 //if checkCvsFiles is true, also check for a change in each files timestamp
@@ -860,7 +957,7 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 	       stateToSet=ES_unknown;
 	       break;
 	    } else if ( (pos = line.find(",v  <--  ")) > 0 ) {//cvs 1.12.xxx series
-	       curCvsFileName = rcsToFileName(line.left(pos));
+	       curCvsFileName = rcsToFileName (line.left (pos));
 	    } else if (line.startsWith("new revision: ") || line.startsWith("initial revision: ") ) {//cvs 1.12.xxx series
 	       if (line.startsWith("new revision: delete")) stateToSet=ES_unknown;
 	       else stateToSet=ES_up_to_date;
@@ -926,6 +1023,8 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 		  locCurCvsState = ES_added;
 	       } else if(line.find("Locally Removed") > -1){
 		  locCurCvsState = ES_removed;
+	       } else if (line.find ("Entry Invalid") > -1) {
+		  locCurCvsState = ES_needs_remove;
 	       }
 
 	       //set state
@@ -959,33 +1058,31 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 		  locCurCvsState = ES_added;
 	       } else if(line.find("Locally Removed") > -1){
 		  locCurCvsState = ES_removed;
+	       } else if (line.find ("Entry Invalid") > -1) {
+		  locCurCvsState = ES_needs_remove;
 	       }
-	    } else if(line.find("Repository revision:") > -1) {//repository of fileName
-	       //repository extrahieren
-	       if((m_repository.find(".")) == 0 && (m_repository.length() == 1)) {// . detected
-		  pos = line.find(m_rootDir);
-	       }
-	       else {
-		  pos = line.find(m_rootDir + "/" + m_repository);
-	       }
-	       repository = line.mid(pos, line.findRev("/") - pos);
-	       if(repository.compare(m_curRepository)) {//different dir than lasttime?
-		  //zugehoeriges dir finden
-		  pCurCvsDir = dyncast_cvsdir(searchDirOfRepository(repository));
-		  if (!pCurCvsDir) { // check for dead trunk
-		     repository = repository.remove(repository.find("/Attic"),6);
-		     pCurCvsDir = dyncast_cvsdir(searchDirOfRepository(repository));
-		  }
-		  m_curRepository = repository;
-	       } else { //not a subdir
-		  if (!pCurCvsDir) {//NULL on first loop
-		     pCurCvsDir = this;
-		  }
-	       }
-	       //set state
-	       if(pCurCvsDir) {
-		  pCurCvsDir->setAndAppendEntry(curCvsFileName, locCurCvsState);
-	       }
+	    } else if ( (line.find("Repository revision:") > -1) && ((pos = line.find ("\t/")) > -1) ) {//repository of fileName
+               QString file = line.mid (pos + 1);
+               file = rcsToFileName (file.left (file.length ()-2));
+
+               if ((pos = file.findRev ("/")) > -1) {
+                  path = file.left (pos);
+                  path = path.stripWhiteSpace ();
+                  file = file.mid (pos + 1);
+                  //is a subdir?
+                  fullPath = m_fullName + "/" + path;
+                  removeDoubleSlashes (fullPath);
+                  //locate dir
+                  pCurCvsDir = dyncast_cvsdir (searchDirOfPath(fullPath));
+               } else {
+                  pCurCvsDir = this;
+               }
+               assert (file == curCvsFileName);
+
+               //set state
+               if(pCurCvsDir) {
+                  pCurCvsDir->setAndAppendEntry(curCvsFileName, locCurCvsState);
+               }
 	    }
 	    break; 
 	 case CVS_GET_TAG_INFO_PROJECT_CMD:
@@ -1068,7 +1165,7 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 	       curCvsFileName = line.mid(2);
 	       locCurCvsState = ES_removed;
 	    } else if(line.find("RCS file: ") == 0) {
-	       curCvsFileName = rcsToFileName(line.left(line.length()-2).mid(10));
+	       curCvsFileName = rcsToFileName (line.left (line.length ()-2).mid (10));
 	       locCurCvsState = ES_modified;
 	    } else if (line.find(": scheduling ") > -1) {
 	       curCvsFileName = line.mid(line.find(": scheduling ")+13);
@@ -1120,7 +1217,7 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 	       if((pos = curCvsFileName.findRev("/")) > -1) 
 		  curCvsFileName = curCvsFileName.mid(pos + 1);
 	   
-	       if(pCurCvsLastUpdateDir) {
+	       if (pCurCvsLastUpdateDir && curCvsFileName.length ()) {
 		  pCurCvsLastUpdateDir->setAndAppendEntry(curCvsFileName, locCurCvsState);
 		  curCvsUpdateFileList.remove(curCvsFileName);
 	       }
@@ -1147,7 +1244,7 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 	       curCvsFileName = line.mid(2);
 	       locCurCvsState = ES_removed;
 	    } else if(line.find("RCS file: ") == 0) {
-	       curCvsFileName = rcsToFileName(line.left(line.length()-2).mid(10));
+	       curCvsFileName = rcsToFileName (line.left (line.length ()-2).mid (10));
 	       locCurCvsState = ES_modified;
 	    } else if (line.find("warning: conflicts during merge") > -1) {//filename allready extracted at <Merging differences between ...>
 	       locCurCvsState = ES_conflict;
@@ -1228,13 +1325,13 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 	       locCurCvsState = ES_modified;
 	    } else if((line.find("U ") == 0)){
 	       curCvsFileName = line.mid(2);
-	       locCurCvsState = ES_needs_checkout;
+	       locCurCvsState = ES_needs_patch;
 	    } else if((line.find("P ") == 0)){
 	       curCvsFileName = line.mid(2);
 	       locCurCvsState = ES_needs_patch;
 	    } else if(line.find("C ") == 0){
 	       curCvsFileName = line.mid(2);
-	       locCurCvsState = ES_conflict;
+	       locCurCvsState = ES_needs_merge;
 	    } else if(line.find("A ") == 0){
 	       curCvsFileName = line.mid(2);
 	       locCurCvsState = ES_added;
@@ -1242,10 +1339,10 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 	       curCvsFileName = line.mid(2);
 	       locCurCvsState = ES_removed;
 	    } else if(line.find("RCS file: ") == 0) {
-	       curCvsFileName = rcsToFileName(line.left(line.length()-2).mid(10));
+               curCvsFileName = rcsToFileName (line.left (line.length ()-2).mid (10));
 	       locCurCvsState = ES_needs_merge;
-	    } else if (line.find("warning: conflicts during merge") > -1) {//filename allready extracted at <Merging differences between ...>
-	       locCurCvsState = ES_conflict;
+// 	    } else if (line.find("warning: conflicts during merge") > -1) {//filename allready extracted at <Merging differences between ...>
+// 	       locCurCvsState = ES_conflict;
 	    } else {
 	       int pos1,pos2;
 	       if (((pos1=line.find("warning: ")) > -1) && ((pos2=line.find(" is not (any longer) pertinent")) > -1)) {
@@ -1256,10 +1353,14 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 		  pos1 += 15;
 		  curCvsFileName = line.mid(pos1,pos2-pos1);
 		  locCurCvsState = ES_missing_dir;
+	       } else if ( ((pos1=line.find (": `")) > -1) && ((pos2=line.find("' is no longer in the repository")) > -1) ) {
+		  pos1 += 3;
+		  curCvsFileName = line.mid(pos1,pos2-pos1);
+		  locCurCvsState = ES_needs_remove;
 	       }
 	    }
 	 
-	    if(locCurCvsState != ES_unknown) {
+	    if (locCurCvsState != ES_unknown) {
 	       removeFileNameInconsistencies(curCvsFileName);
 
 	       curCvsUpdateFileList.remove(m_fullName+"/"+curCvsFileName); //don't set to up-to-date
@@ -1275,7 +1376,11 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 		  removeDoubleSlashes(fullPath);
 		  //locate dir
 		  pCurCvsDir = dyncast_cvsdir(searchDirOfPath(fullPath,VIRTUAL));
-		  if(pCurCvsDir) { //subdir
+		  if (pCurCvsDir) { //subdir
+		     if (locCurCvsState == ES_needs_checkout && pCurCvsDir->m_entries.find(fn)) {
+			//state is bivalent in this case
+			locCurCvsState = ES_needs_patch;
+		     }
 		     switch (locCurCvsState) {
 			case ES_needs_checkout: {
 			   //if file doesn't exists in entries, we have to add it to be displayable in cvs-views
@@ -1302,7 +1407,11 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 			}
 		     }
 		  }
-	       } else {
+	       } else if (curCvsFileName.length ()) {
+		  if (locCurCvsState == ES_needs_checkout && m_entries.find(curCvsFileName)) {
+		     //state is bivalent in this case
+		     locCurCvsState = ES_needs_patch;
+		  }
 		  switch (locCurCvsState) {
 		     case ES_needs_checkout: {
 			//if file doesn't exists in entries, we have to add it to be displayable in cvs-views
@@ -1395,9 +1504,9 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 	    break;
 	 case CVS_MERGE_REV_INTO_CMD:
 	    if (line.find("RCS file: ") == 0) {
-	       curCvsFileName = rcsToFileName(line.left(line.length()-2).mid(10));
+	       curCvsFileName = rcsToFileName (line.left (line.length ()-2).mid (10));
  	       setAndAppendEntry(curCvsFileName, ES_modified);
-	    } else if (line.find("warning: conflicts during merge") > -1) {//filename allready extracted at <Merging differences between ...>
+	    } else if (curCvsFileName.length () && (line.find("warning: conflicts during merge") > -1)) {//filename allready extracted at <Merging differences between ...>
 	       locCurCvsState = ES_conflict;
  	       setAndAppendEntry(curCvsFileName, ES_conflict);
 	    }
@@ -1430,8 +1539,7 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 	       if(pCurCvsDir) { //subdir
 		  pCurCvsDir->setAndAppendEntry(tmp, ES_up_to_date);
 	       }
-	    }
-	    else {
+	    } else if (tmp.length ()) {
 	       setAndAppendEntry(tmp, ES_up_to_date); // local dir
 	    }
 	    curCvsUpdateFileList.remove(file);
@@ -1452,31 +1560,50 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 
 	    QString dirName = addedDirList.first();
 	    CvsDirectory * tmpDir = dyncast_cvsdir(searchLastValidDirOfPath(dirName));
-	    assert(tmpDir);
-	    QString newDir = dirName.left(dirName.find("/",tmpDir->fullName().length()+1));
+            if (tmpDir) {
+               QString newDir = dirName.left(dirName.find("/",tmpDir->fullName().length()+1));
 
-	    if ( !getDisabled(newDir) && tmpDir->fullName().compare(newDir)) {//only add once
-	       //check if exists, don't know wether cvs runns in 'prune empty dirs' mode
-	       QFileInfo info(newDir);
-	       if (info.exists()) {
-	     
-		  if (tmpDir->m_isAnalyzedDir) {//don't continue if not analyzed in on-the-fly-mode
-		     DirBase * vDir = searchDirOfPath(dirName,true);
-		     if (vDir && vDir->isVirtual()) {//remove virtual dir before adding the real dir
-			delete vDir;
-			setDirState(ES_unknown,true);
-		     }
-		     CvsDirectory * unanalyzedDir = dyncast_cvsdir(tmpDir->addDir(newDir));//add in case it was just updated
-		     if (unanalyzedDir && tmpDir->isOpen()) {//will not be analyzed on open() because it is allready open
-			unanalyzedDir->analyzeDirs();
-		     }
-		  }
-	       }
-	    }
+               if ( !getDisabled(newDir) && tmpDir->fullName().compare(newDir)) {//only add once
+                  //check if exists, don't know wether cvs runns in 'prune empty dirs' mode
+                  QFileInfo info(newDir);
+                  if (info.exists()) {
+
+                     if (tmpDir->m_isAnalyzedDir) {//don't continue if not analyzed in on-the-fly-mode
+                        DirBase * vDir = searchDirOfPath(dirName,true);
+                        if (vDir && vDir->isVirtual()) {//remove virtual dir before adding the real dir
+                           delete vDir;
+                           setDirState(ES_unknown,true);
+                        }
+                        CvsDirectory * unanalyzedDir = dyncast_cvsdir(tmpDir->addDir(newDir));//add in case it was just updated
+                        if (unanalyzedDir && tmpDir->isOpen()) {//will not be analyzed on open() because it is allready open
+                           unanalyzedDir->analyzeDirs();
+                        }
+                     }
+                  }
+               }
+            } else {
+               Debug::g_pLog->log (Debug::LL_INFO, "No valid dir path found for: "+dirName);
+            }
 	    addedDirList.remove(dirName);
 	 }
 	 break;
       }
+      case CVS_UNEDIT_CMD: {
+	 if (stringList) {
+	    while (!stringList->isEmpty()) {
+	       QString fileName = stringList->first();
+	       stringList->remove(fileName);
+	       setEntryState(fileName,ES_unknown);
+	       removeEntry(fileName);
+	    }
+	 } else {
+	    m_entries.clear();
+	    QString fileName = "dummy";
+	    setAndAppendEntry(fileName,ES_unknown);
+	    removeEntry(fileName);
+	 }
+	 break;
+      }
       default: {
 	 break;
       }
@@ -1486,10 +1613,43 @@ bool CvsDirectory::parseCallResult(CvsBuffer *output, int icmd, QStringList *str
 
 //--------------------------------------------------------------------------------------------
 
-QString CvsDirectory::rcsToFileName(QString s) {
-   int offset = m_repository.length()+m_rootDir.length()+2;
-   QString fn = s.mid(offset);
-   return fn;
+QString CvsDirectory::rcsToFileName (QString s, bool checkForAttic /* = true */) {
+   assert (!s.isEmpty ());
+   int pos = s.findRev ("/");
+   assert (pos > -1);
+
+   if (checkForAttic && (pos > 6) && (s.mid (pos - 6, 7) == "/Attic/")) {
+      s = s.remove (pos - 6, 6);
+      pos -= 6;
+   }
+
+   QString file = s.mid (pos + 1);
+   QString rcs = m_rootDir + "/" + m_repository + "/";
+
+   if (s.startsWith (rcs)) {
+      QString subPath = s.left (pos).mid (rcs.length ());
+      if (!subPath.isEmpty ()) {
+         CvsDirectory * dir = dyncast_cvsdir (searchDirOfPath (m_fullName + "/" + subPath));//search only for non-virtual dirs
+         if (dir) {
+            QString retVal = dir->rcsToFileName (s, false);
+            if (!retVal.isEmpty ()) {
+               return subPath + "/" + retVal;
+            }
+         }
+      } else {
+         return file;
+      }
+   } else {//iter
+      CvsDirectory * C = firstChild();
+      while( C ) {
+         QString retVal = C->rcsToFileName (s, false);
+         if (!retVal.isEmpty ()) {
+            return C->shortName () + "/" + retVal;
+         }
+         C = C->nextSibling();
+      }
+   }
+   return "";
 }
 
 //--------------------------------------------------------------------------------------------
@@ -1799,6 +1959,10 @@ CvsEntries * CvsDirectory::getCvsEntries(bool resetCache/*=false*/) {
 	 m_modTimeOfEntries = fInfo.lastModified();
 
 	 if (modified && (m_lastCallTime < m_modTimeOfEntries) ) {//clear align-cache, only in case of an external modification of CVS dir
+            if (Debug::g_logLevel == Debug::LL_GOSSIP_MONGER) {
+               logMsg += "Clearing entries cache, callTime: " + m_lastCallTime.toString ("yyyy/MM/dd hh:mm:ss:zzz")
+                  + ", modTimeOfEntries: " + m_modTimeOfEntries.toString ("yyyy/MM/dd hh:mm:ss:zzz");
+            }
 	    m_entries.clear();
 	    m_lastCallTime = m_modTimeOfEntries;
 	 }
@@ -1831,6 +1995,10 @@ CvsEntries * CvsDirectory::getCvsEntries(bool resetCache/*=false*/) {
 	 m_modTimeOfEntriesLog = fInfo.lastModified();
       
 	 if (modified && (m_lastCallTime < m_modTimeOfEntriesLog) ) {//clear align-cache, only in case of an external modification of CVS dir
+            if (Debug::g_logLevel == Debug::LL_GOSSIP_MONGER) {
+               logMsg += "Clearing entries cache, callTime: " + m_lastCallTime.toString ("yyyy/MM/dd hh:mm:ss:zzz")
+                  + ", modTimeOfEntriesLog: " + m_modTimeOfEntriesLog.toString ("yyyy/MM/dd hh:mm:ss:zzz");
+            }
 	    m_entries.clear();
 	    m_lastCallTime = m_modTimeOfEntriesLog;
 	 }
@@ -1911,6 +2079,7 @@ CvsEntries * CvsDirectory::getCvsEntries(bool resetCache/*=false*/) {
 		  } else if (cvsEntry->rev.string == "0") {//only in :local: mode?
 		     cvsEntry->date.dummy = true;
 		     cvsEntry->date.newDummy = false;
+		     cvsEntry->date.string = "";
 		  } else {
 		     cvsEntry->date.dummy = false;
 		     cvsEntry->date.newDummy = false;
@@ -2059,16 +2228,15 @@ EntryStates CvsDirectory::alignWithEntries(QString name, EntryStates stateId) {
 	 {
 	    case ES_modified:
 	       if((entry->state() == ES_needs_patch)
-		     || (entry->state() == ES_needs_merge)) {
+		     || (entry->state() == ES_needs_merge)
+		     || (entry->state() == ES_needs_remove)
+		     || (entry->state() == ES_conflict)) {
 		  entry->setState(entry->state());
 		  stateId = entry->state();
-	       }
-	       else{
-		  if(entry->state() == ES_added) {
-		     stateId = ES_added;
-		  }
-		  else
-		     entry->setState(ES_modified);
+	       } else if(entry->state() == ES_added) {
+		  stateId = ES_added;
+	       } else {
+		  entry->setState(ES_modified);
 	       }
 	       break;
 	    case ES_missing:
@@ -2077,6 +2245,9 @@ EntryStates CvsDirectory::alignWithEntries(QString name, EntryStates stateId) {
 	       } else if (entry->state() == ES_missing_dir) {
 		  stateId = ES_missing_dir;
 		  break;
+	       } else if (entry->state() == ES_needs_remove) {
+		  stateId = ES_needs_remove;
+		  break;
 	       } else if (entry->state() != ES_missing) {
 		  entry->setState(ES_needs_checkout);
 		  stateId = ES_needs_checkout;
@@ -2274,6 +2445,8 @@ inline QString CvsDirectory::getState(const EntryStates & stateId) {
 	 return tr("missing");
       case ES_missing_dir:
 	 return tr("needs checkout");
+      case ES_needs_remove:
+	 return tr("update to remove");
       case ES_conflict:
 	 return tr("conflict");
       case ES_added:
@@ -2297,6 +2470,8 @@ inline char * CvsDirectory::getPix(const EntryStates & stateId, const int & type
 	 return "FileNeedsMerge16x16";
       case ES_needs_checkout:
 	 return "FileNeedsCheckout16x16";
+      case ES_needs_remove:
+	 return "FileRemoved16x16";
       case ES_missing:
 	 return "FileRemoved16x16";
       case ES_missing_dir:
