@@ -1,6 +1,4 @@
 /****************************************************************************
- **
- ** $Id: DiffDialogImpl.cpp,v 1.50 2004/12/20 02:42:11 frank Exp $
  **
  ** Implementation of lincvs' diff tool.
  **
@@ -124,8 +122,13 @@ DiffDialogImpl::DiffDialogImpl(const QIconSet &whatsThisIconSet,
    : DiffDialog(LookAndFeel::g_b0AsParent ? 0 : parent, name, fl)
 {
    Splitter->setStyle(new SplitterStyle(this));
+   Splitter->setOpaqueResize(true);
    m_pWhatsThis->setIconSet(whatsThisIconSet);
-   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
    ButtonLayout->addWidget(new QSizeGrip(this),0,Qt::AlignRight|Qt::AlignBottom);
 
    m_pDiffA->setPartner(m_pDiffB);
