@@ -99,7 +99,11 @@ CEditProfilesDialogImpl::CEditProfilesDialogImpl(QStringList *pUserList,
      m_allowedName(QString::null)
 {
    m_pWhatsThis->setIconSet(whatsThisIconSet);
-   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
    fillCtrls(false);
 }
@@ -122,7 +126,11 @@ CEditProfilesDialogImpl::CEditProfilesDialogImpl(QStringList *pUserList,
      m_profile(profile), m_allowedName(profile.name())
 {
    m_pWhatsThis->setIconSet(whatsThisIconSet);
-   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
    fillCtrls(true);
 }
