@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: EditorsDialogImpl.cpp,v 1.19 2004/12/05 23:38:01 frank Exp $
-**
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
 **    Falk Brettschneider <gigafalk@yahoo.com>
@@ -109,7 +107,11 @@ EditorsDialogImpl::EditorsDialogImpl(const QIconSet &whatsThisIconSet,
     : EditorsDialog( LookAndFeel::g_b0AsParent ? 0 : parent, name, fl )
 {
   m_pWhatsThis->setIconSet(whatsThisIconSet);
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
   ButtonLayout->addWidget(new QSizeGrip(this),0,Qt::AlignRight|Qt::AlignBottom);
 
   connect(EditorsList, SIGNAL(doubleClicked(QListViewItem *)), this, SLOT(viewFile(QListViewItem *)) );
