@@ -1,6 +1,4 @@
 /****************************************************************************
- **
- ** $Id: FileMapperDialogImpl.cpp,v 1.21 2004/12/11 02:20:32 frank Exp $
  **
  ** Copyright (C) 2001-2004 The LinCVS development team.
  **    Tilo Riemer <riemer@lincvs.org>
@@ -145,11 +143,15 @@ FileMapperDialogImpl::FileMapperDialogImpl(Mapping::FileAppList & fileAppList,
 	 m_pFileAppList(&fileAppList), m_tmpPath("") {
 
    m_pWhatsThis->setIconSet(whatsThisIconSet);
-   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
    setCaption( caption);
 
-   QWhatsThis::add(this, tr("To insert, delete or browse dirs, use the context menu.")
+   QWhatsThis::add(this, tr("To insert, delete or browse dirs, use the contextual menu.")
 	 +"\n\n"
 	 +tr("* The 'Match' specifies the affected files.")
 	 +" "+tr("LinCVS will match selected files against these matches from top down. The first exact match will be used.")
@@ -161,7 +163,7 @@ FileMapperDialogImpl::FileMapperDialogImpl(Mapping::FileAppList & fileAppList,
 	 +" "+tr("with the (number)th file of the current selection.")
 	 +" "+tr("'%2' would be replaced with the second selected file name.")
 	 +" "+tr("If you want to invoke your application with special options, this is the place to specify them.")
-	 +" "+tr("Type the options in the way you would use them from the comandline, this should;-) do.")
+	 +" "+tr("Type the options in the way you would use them from the command line, this should;-) do.")
 	 +"\n"
 	 +tr("To open all selected files, specify '%n' here.")
 	 +"\n\n"
