@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: GrabKeyboardImpl.cpp,v 1.8 2004/08/06 22:55:54 tilo Exp $
-**
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
 **    Falk Brettschneider <gigafalk@yahoo.com>
@@ -103,7 +101,11 @@ GrabKeyboardImpl::GrabKeyboardImpl(const QIconSet &whatsThisIconSet,
   : GrabKeyboard(parent,0,TRUE,0), m_blocked(FALSE), m_keySeq(NULL) 
 {
   m_pWhatsThis->setIconSet(whatsThisIconSet);
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
   PrevKey->setText( QString(QKeySequence(oldAccel)) );
 }
