@@ -124,7 +124,11 @@ ImportDialogImpl::ImportDialogImpl( QString* defaultProfile,
 
 {
    m_pWhatsThis->setIconSet(whatsThisIconSet);
-   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
    
    m_VendorTag->setValidator(new TagValidator(m_VendorTag));
    m_ReleaseTag->setValidator(new TagValidator(m_ReleaseTag));
@@ -227,6 +231,8 @@ ImportDialogImpl::ImportDialogImpl( QString* defaultProfile,
    if (!m_defaultProfile->isEmpty()) {
       setDefaultProfile(*m_defaultProfile);
    }
+
+   connect(this,SIGNAL(showWarning(const QString&,const QString&)),parent,SLOT(showWarning(const QString&,const QString&)));
 }
 
 /*  
@@ -418,14 +424,16 @@ void ImportDialogImpl::browseModulesClicked() {
 	    }
 	 }
 
-	 QString strCmd = "checkout -p -n CVSROOT/modules";
-	 QString topModule = QString::null;
-	 BrowseModulesButton->setName("stop action");
-	 BrowseModulesButton->setText(tr("Stop"));
-	 callInteractive( topModule, dir, m_TmpBrowseModulesRoot,
-	       strCmd, CVS_MBROWSEMODULES_CMD,
-	       ExtApps::g_cvsRsh.path,  //additional options of cvsRsh not supported yet
-	       false);
+	 m_ModuleBrowser = new ModuleBrowserImpl(*(m_pWhatsThis->iconSet()),
+	       NULL,
+	       m_TmpBrowseModulesRoot,
+	       m_parent,
+	       this,
+	       "Browse Modules",
+	       true,
+	       LookAndFeel::g_modalF | WDestructiveClose);
+	 connect(m_ModuleBrowser,SIGNAL(OkClicked()),this,SLOT(getAndSetModule()));
+	 m_ModuleBrowser->start();
       }
    }
 }
@@ -467,7 +475,11 @@ void ImportDialogImpl::previewClicked() {
    previewDlg = new ImportPreview(this, NULL, true,
 	 LookAndFeel::g_modalF);
    previewDlg->m_pWhatsThis->setIconSet(*(m_pWhatsThis->iconSet()));
+#ifdef Q_WS_MAC
+   previewDlg->m_pWhatsThis->setMaximumWidth(previewDlg->m_pWhatsThis->height() * 2);
+#else
    previewDlg->m_pWhatsThis->setMaximumWidth(previewDlg->m_pWhatsThis->height());
+#endif
 
    addToPreview(m_ImportDir->currentText().replace(QRegExp ("/+$"),""));
 
@@ -581,17 +593,23 @@ QSize ImportDialogImpl::sizeHint () const {
 
 void ImportDialogImpl::accept() {
 
-   if (m_BrowseModules->currentText().isEmpty()) {
-      QMessageBox::warning(this, tr("Warning"), tr("You have to enter a module name"), QMessageBox::Ok, QMessageBox::NoButton);
+   if (m_RepositoryBox->currentText().isEmpty()) {
+      emit showWarning(tr("Warning"), tr("You have to enter a repository"));
+      return;
+   } else if (m_ImportDir->currentText().isEmpty()) {
+      emit showWarning(tr("Warning"), tr("You have to enter an import dir"));
+      return;
+   } else if (m_BrowseModules->currentText().isEmpty()) {
+      emit showWarning(tr("Warning"), tr("You have to enter a module name"));
       return;
    } else if (m_CommitInfo->text().isEmpty()) {
-      QMessageBox::warning(this, tr("Warning"), tr("You have to enter an import message"), QMessageBox::Ok, QMessageBox::NoButton);
+      emit showWarning(tr("Warning"), tr("You have to enter an import message"));
       return;
    } else if (m_VendorTag->currentText().isEmpty()) {
-      QMessageBox::warning(this, tr("Warning"), tr("You have to enter a vendor tag"), QMessageBox::Ok, QMessageBox::NoButton);
+      emit showWarning(tr("Warning"), tr("You have to enter a vendor tag"));
       return;
    } else if (m_ReleaseTag->currentText().isEmpty()) {
-      QMessageBox::warning(this, tr("Warning"), tr("You have to enter a release tag"), QMessageBox::Ok, QMessageBox::NoButton);
+      emit showWarning(tr("Warning"), tr("You have to enter a release tag"));
       return;
    }
    ImportDialog::accept();
@@ -665,6 +683,7 @@ int ImportDialogImpl::rshMode() {
 
 void ImportDialogImpl::getAndSetModule() {
    m_BrowseModules->setCurrentText(m_ModuleBrowser->getModule());
+   m_ModuleBrowser = NULL;
 }
 
 void ImportDialogImpl::insertModule(const QString& module) {
@@ -706,93 +725,13 @@ void ImportDialogImpl::cvsCallFinished() {
    m_running = false;
 }
 
-void ImportDialogImpl::afterCall( int cmd, CvsBuffer* output, bool failed) {
+void ImportDialogImpl::afterCall( int, CvsBuffer*, bool failed) {
    cvsCallFinished();
 
-   switch (cmd) {
-      case CVS_MBROWSEMODULES_CMD: {
-	 if (failed) {
-	    BrowseModulesButton->setName(m_defBrowseModButtonName);
-	    BrowseModulesButton->setText(m_defBrowseModButtonText);
-	    return;
-	 }
-	 bool fileOk = false;
-	 QString line;
-	 unsigned int len = (*output).numLines();
-	 unsigned int skipLines = outputLineOffset + 6;
-	 for ( unsigned int i = skipLines; i<len;i++) {//only two lines if no CVSROOT/modules file
-	    line = (*output).textLine(i);
-	    if ( (line.at(0)!='#') && ( !(line.isEmpty()) ) ) {
-	       fileOk = true;
-	       break;
-	    }
-	 }
-	 if (!fileOk) {
-	    int sshAccess = getSshPreset();
-	    //check ssh access settings
-	    bUseSsh = false;
-	    bUseSshAgent = false;
-	    bUseSshAgentVars = false;
-	    switch( sshAccess) {
-	       case USESSH: {
-		  bUseSsh = true;
-		  break;
-	       }
-	       case USESSHAGENT: {
-		  bUseSshAgent = true;
-		  break;
-	       }
-	       case USESSHAGENTVARS: {
-		  bUseSshAgentVars = true;
-		  break;
-	       }
-	    }
-	    QString dir = "";
-	    QString files = "history -xAMR -a -l";
-	    QString topModule = QString::null;
-	    callInteractive( topModule, dir, m_TmpBrowseModulesRoot,
-		  files, CVS_HBROWSEMODULES_CMD,
-		  ExtApps::g_cvsRsh.path,  //additional options of cvsRsh not supported yet
-		  false);
-	    return;
-	 } else {
-	    BrowseModulesButton->setName(m_defBrowseModButtonName);
-	    BrowseModulesButton->setText(m_defBrowseModButtonText);
-	    m_ModuleBrowser = new ModuleBrowserImpl(*(m_pWhatsThis->iconSet()),
-		  NULL,
-		  m_TmpBrowseModulesRoot,
-		  m_parent,
-		  this,
-		  "Browse Modules",
-		  true,
-		  LookAndFeel::g_modalF | WDestructiveClose);
-	    connect(m_ModuleBrowser,SIGNAL(OkClicked()),this,SLOT(getAndSetModule()));
-	    m_ModuleBrowser->parseModules (output);
-	    m_ModuleBrowser->show();
-	 }
-	 break;
-      }
-      case CVS_HBROWSEMODULES_CMD: {
-	 if (failed) {
-	    BrowseModulesButton->setName(m_defBrowseModButtonName);
-	    BrowseModulesButton->setText(m_defBrowseModButtonText);
-	    return;
-	 }
-	 BrowseModulesButton->setName(m_defBrowseModButtonName);
-	 BrowseModulesButton->setText(m_defBrowseModButtonText);
-	 m_ModuleBrowser = new ModuleBrowserImpl(*(m_pWhatsThis->iconSet()),
-	       NULL,
-	       m_TmpBrowseModulesRoot,
-	       m_parent,
-	       this,
-	       "Browse Modules",
-	       true,
-	       LookAndFeel::g_modalF | WDestructiveClose);
-	 connect(m_ModuleBrowser,SIGNAL(OkClicked()),this,SLOT(getAndSetModule()));
-	 m_ModuleBrowser->parseHistory (output);
-	 m_ModuleBrowser->show();
-	 break;
-      }
+   if (failed) {
+      BrowseModulesButton->setName(m_defBrowseModButtonName);
+      BrowseModulesButton->setText(m_defBrowseModButtonText);
+      return;
    }
 }
 
