@@ -1,8 +1,6 @@
 /****************************************************************************
  **
- ** $Id: InteractiveCmdThread.cpp,v 1.45 2004/12/08 15:50:02 frank Exp $
- **
- ** Copyright (C) 2001-2004 Frank Hemer <frank@hemer.org>
+ ** Copyright (C) 2001-2005 Frank Hemer <frank@hemer.org>
  **
  **
  **----------------------------------------------------------------------------
@@ -122,31 +120,39 @@ InteractiveCmdThread::~InteractiveCmdThread () {
 //------------------------------------------------------------------------------------
 
 bool InteractiveCmdThread::start() {
-
-   //read environment settings
-   //make sure this is only called once and kept till end of thread,
-   //in case more than one call is executed (concatenated with && )
-   //and the following commands might need these env too!
-   delete m_pEnvironment;
-   m_pEnvironment = new QStringList();
-#ifdef Q_WS_WIN
-   setEnv();
+	
+	//read environment settings
+	//make sure this is only called once and kept till end of thread,
+	//in case more than one call is executed (concatenated with && )
+	//and the following commands might need these env too!
+	delete m_pEnvironment;
+	m_pEnvironment = new QStringList();
+	
+	m_pEnvironment->append("CVS_PASSFILE="+CVSPASSPATH);
+	
+#ifdef Q_WS_MAC
+	QString askpass = APPDIR + "/" + LC_TOOLS_DIR + "/ssh-askpass.app/Contents/MacOS/ssh-askpass";
 #else
-   m_pEnvironment->append("CVS_PASSFILE="+CVSPASSPATH);
-   QString askpass = APPDIR + "/" + LC_TOOLS_DIR + "/ssh-askpass.bin";
-   if (QFileInfo(askpass).exists()) {
-      m_pEnvironment->append("SSH_ASKPASS="+askpass);
-   } else {
-      addToEnv("SSH_ASKPASS");
-   }
-   addToEnv("DISPLAY");
-   //  Have the process inherit the PATH setting so that ssh and other 
-   //  commands can be found
-   addToEnv("PATH");  // don not add PATH on Win (it is implicitely added by QProcess
+	QString askpass = APPDIR + "/" + LC_TOOLS_DIR + "/ssh-askpass.bin";
 #endif
-   addToEnv("HOME");
-
-   return run();
+	if (QFileInfo(askpass).exists()) {
+		m_pEnvironment->append("SSH_ASKPASS="+askpass);
+	} else {
+		addToEnv("SSH_ASKPASS");
+	}
+	
+#ifdef Q_WS_MAC
+	if (!addToEnv("DISPLAY")) m_pEnvironment->append("DISPLAY=:0.0");
+#else
+	addToEnv("DISPLAY");
+#endif
+	
+	//  Have the process inherit the PATH setting so that ssh and other 
+	//  commands can be found
+	addToEnv("PATH");
+	addToEnv("HOME");
+	
+	return run();
 }
 
 //-------------------------------------------------------------------------------------
@@ -199,8 +205,10 @@ bool InteractiveCmdThread::run () {
    m_command += " " + m_module;
 
    //write cmd to message window
-   m_pCvsBuffer->append("cmd: "+m_command+getSystemLF());
-   m_pMessages->insert("cmd: "+m_command+getSystemLF());
+   QString commandWithoutPlaceholder = m_command;
+   commandWithoutPlaceholder.replace(PLACEHOLDER_FOR_QUOTATION_MARKS, "\"");
+   m_pCvsBuffer->append("cmd: "+commandWithoutPlaceholder+getSystemLF());
+   m_pMessages->insert("cmd: "+commandWithoutPlaceholder+getSystemLF());
 
    //split command options and prevent doublequoted strings from being split
    //the doublequotes are removed though
@@ -216,10 +224,10 @@ bool InteractiveCmdThread::run () {
       if (pos % 2) {
          QStringList tmpList = QStringList::split(" ",(*outer));
          for ( QStringList::Iterator inner = tmpList.begin(); inner != tmpList.end(); ++inner ) {
-            commandArgs.append(*inner);
+            commandArgs.append((*inner).replace(PLACEHOLDER_FOR_QUOTATION_MARKS, "\""));
          }
       } else {
-         commandArgs.append(*outer);
+         commandArgs.append((*outer).replace(PLACEHOLDER_FOR_QUOTATION_MARKS, "\""));
       }
       ++pos;
       ++outer;
