@@ -1,8 +1,6 @@
 /****************************************************************************
  **
- ** $Id: LogDialogImpl.cpp,v 1.121.2.1 2005/01/16 18:44:02 frank Exp $
- **
- ** Copyright (C) 2001-2004 The LinCVS development team.
+ ** Copyright (C) 2001-2005 The LinCVS development team.
  **    Tilo Riemer <riemer@lincvs.org>
  **    Falk Brettschneider <gigafalk@yahoo.com>
  **    Frank Hemer <frank@hemer.org>
@@ -110,7 +108,6 @@
 #include "AnnotateDialogImpl.h"
 #include "LogDialogImpl.h"
 #include "globals.h"
-#include "tzconvert.h"
 #include "pixmapcache.h"
 #include "colortab.h"
 #include "VerifyDialog.h"
@@ -130,7 +127,11 @@ LogDialogImpl::LogDialogImpl(CvsDirListView * workBench,
      m_treeA(0), m_treeB(0), m_parent(parent)
 {
    m_pWhatsThis->setIconSet(whatsThisIconSet);
-   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
    buttonLayout->addWidget(new QSizeGrip(this),0,Qt::AlignRight|Qt::AlignBottom);
 
    connect(this,SIGNAL(checkInProgress(bool)),parent,SLOT(checkInProgress(bool)));
@@ -290,8 +291,7 @@ void LogDialogImpl::parseCvsLog (QString BaseDir, QString name, QString revision
 	     */
 	    strlist = QStringList::split (';', line);
 	    QString tmpVal = (QStringList::split (": ", strlist[0]))[1];
-	    QDateTime t = QDateTime::fromString(tmpVal.replace(10,1,(const char*)"T"),Qt::ISODate );
-	    date = getAsLocal(t,FALSE);
+	    date = QDateTime::fromString(tmpVal.replace(10,1,(const char*)"T"),Qt::ISODate );
 	    author = (QStringList::split (": ", strlist[1]))[1];
 	    state = (QStringList::split (": ", strlist[2]))[1];
 	    lines="";kopt="";commitid="";mergepoint="";filename="";
@@ -436,7 +436,8 @@ void LogDialogImpl::parseCvsLog (QString BaseDir, QString name, QString revision
  */
 void LogDialogImpl::annotateClicked() {
    QString cvsRoot = "annotate -r " + m_selectionA;
-   QString file = masqWs(m_fileA);
+   QString fileA = m_fileA;
+   QString file = masqWs(fileA.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS));
    callInteractive( m_topModule, m_baseDir, cvsRoot,
 	 file, CVS_ANNOTATE_CMD,
 	 ExtApps::g_cvsRsh.path,  //additional options of cvsRsh not supported yet
@@ -467,7 +468,8 @@ void LogDialogImpl::runDisplayFileRevision( QString &rev, QString &fileName) {
 
    m_tmpDiffFileNameA = createTempFile("-" + rev + "-" + fileName);
    if (!m_tmpDiffFileNameA.isEmpty()) {
-      QString cvsRoot = "-Q update -p -r " + rev + " " + masqWs(fileName) + " > " + m_tmpDiffFileNameA;
+      QString tmpFile = fileName;
+      QString cvsRoot = "-Q update -p -r " + rev + " " + masqWs(tmpFile.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS)) + " > " + m_tmpDiffFileNameA;
       QString file = "";
       callInteractive( m_topModule, m_baseDir, cvsRoot,
 	    file, CVS_EDIT_REVISION_CMD,
@@ -493,13 +495,13 @@ void LogDialogImpl::diff(QString revA, QString revB, QString fileA, QString file
    if (bUSEEXTERNALDIFFFORSIDEBYSIDE) {
       QString cvsRoot = CvsOptions::cmprStr() + " -Q update ";
 
-      m_tmpDiffFileNameB = createTempFile("-" + fileB + "-" + revB);
+      m_tmpDiffFileNameB = createTempFile("-" + revB + "-" + fileB);
       if (!m_tmpDiffFileNameB.isEmpty()) {
 	 if (!revA.isEmpty()) {
-	    m_tmpDiffFileNameA = createTempFile("-" + fileA + "-" + revA);
+	    m_tmpDiffFileNameA = createTempFile("-" + revA + "-" + fileA);
 	    if (!m_tmpDiffFileNameA.isEmpty()) {
 	       if (bKeywordSuppression) cvsRoot += "-kk ";
-	       cvsRoot += "-p -r " + revA + " " + masqWs(fileA) + " > " + m_tmpDiffFileNameA
+	       cvsRoot += "-p -r " + revA + " " + masqWs(fileA.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS)) + " > " + m_tmpDiffFileNameA
 		  + " && cvs " + CvsOptions::cmprStr() + " -Q update ";
 	       if (bKeywordSuppression) cvsRoot += "-kk ";
 	       m_sandbox = m_baseDir + "/" + fileA;
@@ -510,7 +512,7 @@ void LogDialogImpl::diff(QString revA, QString revB, QString fileA, QString file
 	 // diff between two revisions or between sandbox and one revision
 	 // but we use m_sandbox for 3way diff...
       
-	 cvsRoot += "-p -r " + revB + " " + masqWs(fileB) + " > " + m_tmpDiffFileNameB;
+	 cvsRoot += "-p -r " + revB + " " + masqWs(fileB.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS)) + " > " + m_tmpDiffFileNameB;
 	 if (revA.isEmpty()) {//diff against local rep, exchange diff file order
 	    QString tmp = m_tmpDiffFileNameA;
 	    m_tmpDiffFileNameA = m_tmpDiffFileNameB;
@@ -532,7 +534,7 @@ void LogDialogImpl::diff(QString revA, QString revB, QString fileA, QString file
       cvsRoot += "--side-by-side -t -W "+hlp.setNum(SIDEWIDTH);
       if (!revA.isEmpty()) cvsRoot += " -r " + revA;
       cvsRoot += " -r " + revB;
-      QString file =  masqWs(fileA);
+      QString file =  masqWs(fileA.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS));
       callInteractive( m_topModule, m_baseDir, cvsRoot,
 	    file, CVS_DIFF_SBS_CMD,
 	    ExtApps::g_cvsRsh.path,  //additional options of cvsRsh not supported yet
@@ -561,7 +563,8 @@ void LogDialogImpl::diffConsoleClicked() {
    if (bKeywordSuppression) cvsRoot += "-kk ";
    if (!m_selectionA.isEmpty()) cvsRoot += " -r " + m_selectionA;
    if (!m_selectionB.isEmpty()) cvsRoot += " -r " + m_selectionB;
-   QString file =  masqWs(m_fileA);
+   QString fileA = m_fileA;
+   QString file =  masqWs(fileA.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS));
    callInteractive( m_topModule, m_baseDir, cvsRoot,
 	 file, CVS_DIFF_CMD,
 	 ExtApps::g_cvsRsh.path,  //additional options of cvsRsh not supported yet
@@ -585,7 +588,8 @@ void LogDialogImpl::diffConsoleSandBox(const QString &rev, const QString &f) {
    if (bDiffIgnoreWhiteSpace) cvsRoot += "-b -B ";
    if (bKeywordSuppression) cvsRoot += "-kk ";
    cvsRoot += " -r " + rev;
-   QString file =  masqWs(f);
+   QString tmpFile = f;
+   QString file =  masqWs(tmpFile.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS));
    callInteractive( m_topModule, m_baseDir, cvsRoot,
 	 file, CVS_DIFF_CMD,
 	 ExtApps::g_cvsRsh.path,  //additional options of cvsRsh not supported yet
@@ -596,7 +600,7 @@ void LogDialogImpl::createPatchClicked() {
 
    bool ok;
    QString dir = m_baseDir + "/" + m_fileA + "-diff-" + m_selectionA + "-" + m_selectionB;
-   QString patchFile = QInputDialog::getText(tr("Enter file name (default:") + dir + ")",
+   QString patchFile = QInputDialog::getText(tr("Enter file name (default:") + " " + dir + ")",
 	 "Enter a file name for the patch file", QLineEdit::Normal,
 	 dir, &ok, this, "Patch file dialog");
 
@@ -618,7 +622,8 @@ void LogDialogImpl::createPatchClicked() {
    if (CvsOptions::g_bUnifiedDiffOutput) cvsRoot += "-u ";
    if (!m_selectionA.isEmpty()) cvsRoot += " -r " + m_selectionA;
    if (!m_selectionB.isEmpty()) cvsRoot += " -r " + m_selectionB;
-   cvsRoot +=  " " + masqWs(m_fileA) + " > " + patchFile;
+   QString fileA = m_fileA;
+   cvsRoot +=  " " + masqWs(fileA.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS)) + " > " + patchFile;
    QString file = "";
    callInteractive( m_topModule, m_baseDir, cvsRoot,
 	 file, CVS_NOT_INTERACTIVE_CMD,
@@ -655,7 +660,8 @@ void LogDialogImpl::mergeClicked() {
       if (bKeywordSuppression) command += "-kk ";
       command += "-j " + m_selectionA;
       command += " -j " + m_selectionB;
-      QString file = masqWs(m_fileA);
+      QString fileA = m_fileA;
+      QString file = masqWs(fileA.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS));
       callInteractive( m_topModule, m_baseDir, command,
 	    file, CVS_MERGE_REV_INTO_CMD,
 	    ExtApps::g_cvsRsh.path,  //additional options of cvsRsh not supported yet
@@ -727,7 +733,7 @@ void LogDialogImpl::setButtonsAndSelectedPair(int treeA, int treeB) {
    buttonDiffs->setEnabled( bool ( bothRevsSet &&
 				  ((sameTree && !sameRev) ||
 					(!sameTree && bUSEEXTERNALDIFFFORSIDEBYSIDE)) ));
-   
+
    m_ButtonDiffConsole->setEnabled( bool (sameTree &&
 					  !m_selectionA.isNull() &&
 					  !m_selectionB.isNull() &&
@@ -821,10 +827,15 @@ void LogDialogImpl::afterCall( int cmd, CvsBuffer * buf, bool failed) {
       case CVS_DIFF_EXT_CMD: {
 	 QString diffPrg = "\"" + ExtApps::g_diffProg.path + "\" ";
 	 QStringList nameList;
-	 nameList.append(m_tmpDiffFileNameA);
-	 nameList.append(m_tmpDiffFileNameB);
+	 QString tmp = m_tmpDiffFileNameA;
+	 nameList.append(tmp.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS));
+	 tmp = m_tmpDiffFileNameB;
+	 nameList.append(tmp.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS));
 	 if (m_sandbox.isEmpty()) nameList.append("");
-	 else nameList.append(m_sandbox);
+	 else {
+	    tmp = m_sandbox;
+	    nameList.append(tmp.replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS));
+	 }
 	 QString options = ExtApps::g_diffProg.options;
 	 if (masqedFilenamesForPlaceholders(options, nameList)) diffPrg += options;
 	 else {// no options, we add filenames assuming the user want it so ;-)
