@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: ModuleBrowserImpl.h,v 1.12 2004/08/18 11:53:46 frank Exp $
-**
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
 **    Falk Brettschneider <gigafalk@yahoo.com>
@@ -114,12 +112,14 @@ public:
   ~ModuleBrowserImpl();
   void parseHistory ( CvsBuffer *output);
   void parseModules ( CvsBuffer *output);
+  void parseRls ( CvsBuffer *output);
  
   QString getModule();
   QString getCheckoutAsDOption();
   void afterCall(int,CvsBuffer*,bool);
 
 public slots:
+  void start();
   void toggleBrowseHorM();
   void select();
   void accept();
