@@ -99,7 +99,11 @@ CProfilesDialogImpl::CProfilesDialogImpl(QStringList *pUserList,
      m_profileContentList(profileContentList)
 {
    m_pWhatsThis->setIconSet(whatsThisIconSet);
+#ifdef Q_WS_MAC
+   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
    m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
    fillListView();
    enableButtons();
