@@ -1,6 +1,4 @@
 /****************************************************************************
- **
- ** $Id: ResolvDialogImpl.cpp,v 1.41 2004/12/20 02:42:11 frank Exp $
  **
  ** Copyright (C) 2001-2004 Frank Hemer <frank@hemer.org>
  **
@@ -132,7 +130,7 @@ ResolvDialogImpl::ResolvDialogImpl( QString fileName,
       QString revision)
    : ResolvDialog( LookAndFeel::g_b0AsParent ? 0 : parent, "ResolvDialog", fl)
 {
-   setCaption ("LinCVS Resolve - " + fileName.mid(fileName.findRev("/")+1) + " " + revision);
+   setCaption (tr("LinCVS Resolve") + " - " + fileName.mid(fileName.findRev("/")+1) + " " + revision);
 
    Splitter->setStyle(new SplitterStyle(this));
 
@@ -159,7 +157,11 @@ void ResolvDialogImpl::init(const QIconSet & whatsThisIconSet,QString & fileName
    m_currentBlock = NULL;
 
    m_pWhatsThis->setIconSet(whatsThisIconSet);
-   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
    ButtonLayout->addWidget(new QSizeGrip(this),0,Qt::AlignRight|Qt::AlignBottom);
    ButtonLabel->setAlignment(Qt::AlignHCenter|AlignVCenter);
 
@@ -216,12 +218,12 @@ void ResolvDialogImpl::init(const QIconSet & whatsThisIconSet,QString & fileName
    connect(m_FileMerged,SIGNAL(clicked(int,int)),this,SLOT(clear(int,int)));
 
    QWhatsThis::add( m_FileLeft,
-	 tr( "This file holds the state the file was in befor the conflict causing cvs call.\n"
+	 tr( "This file holds the state the file was in before the conflict causing cvs call.\n"
 	       "\n"
-	       "ResolvDialog howto:\n"
+	       "Resolve Dialog howto:\n"
 	       "\n"
-	       "left klick into the line number bar:\n"
-	       "-on a seleted line: 	deselects the whole block\n"
+	       "left click into the line-number bar:\n"
+	       "-on a selected line: 	deselects the whole block\n"
 	       "-on an unselected line: 	select the whole block\n"
 	       "\n"
 	       "left click into a conflict block:\n"
@@ -237,7 +239,7 @@ void ResolvDialogImpl::init(const QIconSet & whatsThisIconSet,QString & fileName
 	       "goto next/previous line:	arrow down/up\n"
 	       "goto next/previous block:	<ctrl>arrow down/up\n"
 	       "scroll half page up/down:	page up/down\n"
-	       "goto begining/end:	Home/End\n"
+	       "goto beginning/end:	Home/End\n"
 	       "\n"
 	       "Special feature for the merged file:\n"
 	       "remove a line:	Delete\n"
@@ -248,15 +250,15 @@ void ResolvDialogImpl::init(const QIconSet & whatsThisIconSet,QString & fileName
 	       "white: non-conflicting code segments\n"
 	       "dark gray: conflict markers and line numbers\n"
 	       "red: conflicting code parts\n"
-	       "light gray: space added for clearity\n"
+	       "light gray: space added for clarity\n"
 	       "blue: selected lines" ) );
    QWhatsThis::add( m_FileRight,
-	 tr( "This file represents the part of the file that was merged in with the conflict causing cvs call.\n"
+	 tr( "This file represents the part of the file that was merged in by the conflict-causing cvs call.\n"
 	       "\n"
-	       "ResolvDialog howto:\n"
+	       "Resolve Dialog howto:\n"
 	       "\n"
-	       "left klick into the line number bar:\n"
-	       "-on a seleted line: 	deselects the whole block\n"
+	       "left click into the line-number bar:\n"
+	       "-on a selected line: 	deselects the whole block\n"
 	       "-on an unselected line: 	select the whole block\n"
 	       "\n"
 	       "left click into a conflict block:\n"
@@ -272,7 +274,7 @@ void ResolvDialogImpl::init(const QIconSet & whatsThisIconSet,QString & fileName
 	       "goto next/previous line:	arrow down/up\n"
 	       "goto next/previous block:	<ctrl>arrow down/up\n"
 	       "scroll half page up/down:	page up/down\n"
-	       "goto begining/end:	Home/End\n"
+	       "goto beginning/end:	Home/End\n"
 	       "\n"
 	       "Special feature for the merged file:\n"
 	       "remove a line:	Delete\n"
@@ -283,15 +285,15 @@ void ResolvDialogImpl::init(const QIconSet & whatsThisIconSet,QString & fileName
 	       "white: non-conflicting code segments\n"
 	       "dark gray: conflict markers and line numbers\n"
 	       "red: conflicting code parts\n"
-	       "light gray: space added for clearity\n"
+	       "light gray: space added for clarity\n"
 	       "blue: selected lines" ) );
    QWhatsThis::add( m_FileMerged,
 	 tr( "This file holds the merged state. The conflict markers of solved conflicts will be removed when the file is saved.\n"
 	       "\n"
-	       "ResolvDialog howto:\n"
+	       "Resolve Dialog howto:\n"
 	       "\n"
-	       "left klick into the line number bar:\n"
-	       "-on a seleted line: 	deselects the whole block\n"
+	       "left click into the line-number bar:\n"
+	       "-on a selected line: 	deselects the whole block\n"
 	       "-on an unselected line: 	select the whole block\n"
 	       "\n"
 	       "left click into a conflict block:\n"
@@ -307,7 +309,7 @@ void ResolvDialogImpl::init(const QIconSet & whatsThisIconSet,QString & fileName
 	       "goto next/previous line:	arrow down/up\n"
 	       "goto next/previous block:	<ctrl>arrow down/up\n"
 	       "scroll half page up/down:	page up/down\n"
-	       "goto begining/end:	Home/End\n"
+	       "goto beginning/end:	Home/End\n"
 	       "\n"
 	       "Special feature for the merged file:\n"
 	       "remove a line:	Delete\n"
