@@ -1,6 +1,4 @@
 /****************************************************************************
- **
- ** $Id: ResolvDialogImpl.h,v 1.18 2004/12/10 16:48:09 frank Exp $
  **
  ** Copyright (C) 2001-2004 Frank Hemer <frank@hemer.org>
  **
@@ -156,7 +154,12 @@ class ResolvDialogImpl : public ResolvDialog {
       int fileTable;
       int line;
    };
-   
+
+   // Sun Forte 5.3 does not allow embedded classes access to protected
+   // or private data without explict 'friend' statements.
+   class Block;
+   friend class Block;
+
    class Block {
     public:
       Block();
