@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: RevisionWidgetImpl.cpp,v 1.12 2004/10/08 23:15:23 frank Exp $
-**
 ** Copyright (C) 2003-2004 Frank Hemer <frank@hemer.org>
 **
 **
@@ -135,11 +133,11 @@ void RevisionWidgetImpl::init( QObject * connectionSrc,
 
     if (m_topModuleName != QString::null) {
       connect( this, SIGNAL(getProjectTags()), connectionSrc, SLOT(updateProjectTagList()) );
+    } else {
+      m_fetchOverall = FALSE;
     }
     if (tagList != NULL) {
       connect( this, SIGNAL(getSelectedTags()), connectionSrc, SLOT(readCurrentTagList()));
-    } else {
-      m_fetchOverall = FALSE;
     }
 
   } else {
@@ -155,6 +153,18 @@ void RevisionWidgetImpl::init( QObject * connectionSrc,
   m_DateTime->setDateTime(QDateTime::currentDateTime());
 }
 
+void RevisionWidgetImpl::setEnabled(bool state) {
+   HeadButton->setEnabled(state);
+   OtherButton->setEnabled(state);
+   SetStickyTagButton->setEnabled(state);
+   TagDateButton->setEnabled(state);
+   RevisionButton->setEnabled(state);
+   m_TagBox->setEnabled(state);
+   TagButton->setEnabled(state);
+   DateButton->setEnabled(state);
+   m_DateTime->setEnabled(state && DateButton->isChecked());
+}
+
 void RevisionWidgetImpl::readProjectNameList() {
   m_ProjectTagList.clear();
   projectSettings->get(m_topModuleName,PROJECTTAGLIST,m_ProjectTagList);
@@ -197,7 +207,7 @@ QString RevisionWidgetImpl::getTag() {
 }
 
 QString RevisionWidgetImpl::getDateTime() {
-  if (m_DateTime->isEnabled()) return m_DateTime->dateTime().toString("yyyy-MM-dd hh:mm");
+  if (m_DateTime->isEnabled()) return m_DateTime->dateTime().toString("yyyy-MM-dd hh:mm:ss");
   else return QString::null;
 }
 
