@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: TagStdDialogImpl.cpp,v 1.15 2004/12/03 00:28:04 tilo Exp $
-**
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
 **    Falk Brettschneider <gigafalk@yahoo.com>
@@ -127,7 +125,11 @@ TagStdDialogImpl::TagStdDialogImpl( QString module, QStringList * list, QString
 {
 
   m_pWhatsThis->setIconSet(whatsThisIconSet);
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
   if (bUseSmallIcons) setIcon( findEmbeddedPixmap( "Tag16x16" ) );
   else setIcon( findEmbeddedPixmap( "Tag32x32" ) );
@@ -178,7 +180,7 @@ QString TagStdDialogImpl::getCommand() {
   if (OtherRevisionButton->isChecked()) {
     if (RevisionButton->isChecked()) command += "-r "+m_Revision->text()+" ";
     if (TagButton->isChecked()) command += "-r "+m_pSecondTag->currentText()+" ";
-    if (DateButton->isChecked()) command += "-D \""+m_DateTime->dateTime().toString("yyyy-MM-dd hh:mm")+"\" ";
+    if (DateButton->isChecked()) command += "-D "+masqWs(m_DateTime->dateTime().toString("yyyy-MM-dd hh:mm:ss"))+" ";
   }
 
   switch( TagOperationGroup->id(TagOperationGroup->selected()) ) {
