@@ -1,8 +1,6 @@
 /****************************************************************************
  **
- ** $Id: Update.cpp,v 1.16.2.1 2005/01/18 01:17:13 frank Exp $
- **
- ** Copyright (C) 2001-2004 Tilo Riemer <riemer@lincvs.org> and
+ ** Copyright (C) 2001-2005 Tilo Riemer <riemer@lincvs.org> and
  **                         Frank Hemer <frank@hemer.org>
  **
  **
@@ -214,7 +212,7 @@ Update * Update::setup(const QIconSet &whatsThisIconSet,
 	       dlg = new UpdateOtherRevisionStdDialogImpl( moreThanOneFile,
 		     tagList,
 		     moduleName,
-		     tr("Update Other Revision (DIR)"),
+		     tr("Update Other Revision (FILES)"),
 		     whatsThisIconSet,
 		     parent, "Update Other Revision",
 		     true,  //modal
@@ -250,7 +248,7 @@ Update * Update::setup(const QIconSet &whatsThisIconSet,
 	       dlg = new UpdateOtherRevisionDialogImpl( true,
 		     tagList,
 		     moduleName,
-		     tr("Update Other Revision (FILES)"),
+		     tr("Update Other Revision (DIR)"),
 		     whatsThisIconSet,
 		     parent, "Update Other Revision",
 		     true,  //modal
@@ -342,10 +340,12 @@ void Update::acceptCvs() {
    if (!m_isDir) {
       m_selectedFilesList = m_dir->getSelectedFiles();
       if (m_selectedFilesList.isEmpty()) {
-	 reject(false);
-	 return;
+         reject(false);
+         return;
       }
-      m_selectedFiles = masqWs(m_selectedFilesList.join("\" \""));
+      QStringList list = m_selectedFilesList;
+      masqQuoteMarks(&list);
+      m_selectedFiles = masqWs(list.join("\" \""));
    } else {
       m_selectedFiles = "";
    }
@@ -357,84 +357,84 @@ void Update::acceptCvs() {
    QString files = "";
    switch(m_mode) {
       case QUERYFILE: {
-	 command += " -n update " + m_selectedFiles;
-	 cmd = CVS_QUERY_UPDATE_CMD;
-	 break;
+         command += " -n update " + m_selectedFiles;
+         cmd = CVS_QUERY_UPDATE_CMD;
+         break;
       }
       case FILE: {
-	 command += " update " + m_selectedFiles;
-	 cmd = CVS_UPDATE_FILES_CMD;
-	 break;
+         command += " update " + m_selectedFiles;
+         cmd = CVS_UPDATE_FILES_CMD;
+         break;
       }
       case REPLACEFILE: {
-	 command += " update -C " + m_selectedFiles;
-	 cmd = CVS_UPDATE_FILES_CMD;
-	 break;
+         command += " update -C " + m_selectedFiles;
+         cmd = CVS_UPDATE_FILES_CMD;
+         break;
       }
       case BRANCHFILE: {
-	 QString dirBranch = m_dir->getDirTag();
-	 QString dirType = "";
-	 if (!dirBranch.isEmpty()) {
-	    dirType = dirBranch.left(1);
-	    dirBranch = dirBranch.mid(1);
-	 }
-	 if (dirBranch.isEmpty()) {
-	    emit showWarning( tr("update to branch of dir"), tr("The selected dir has\nno branch tag set") );
-	    reject(false);
-	    return;
-	 }
-	 command += " update ";
-	 if (!dirBranch.isEmpty()) {
-	    if (dirType=="T" || dirType=="N") {
-	       command += "-r " + dirBranch + " ";
-	    } else if (dirType=="D") {
-	       command += "-D " + dirBranch + " ";
-	    } else {
-	       Debug::g_pLog->log(Debug::LL_THE_OLD_MAN_AND_THE_SEA,"unknown dirBranchType: ->"+dirType+"<-");
-	    }
-	 }
-	 command += m_selectedFiles;
-	 cmd = CVS_UPDATE_FILES_CMD;
-	 break;
+         QString dirBranch = m_dir->getDirTag();
+         QString dirType = "";
+         if (!dirBranch.isEmpty()) {
+            dirType = dirBranch.left(1);
+            dirBranch = dirBranch.mid(1);
+      }
+      if (dirBranch.isEmpty()) {
+         emit showWarning( tr("update to branch of dir"), tr("The selected dir has\nno branch tag set") );
+         reject(false);
+         return;
+      }
+      command += " update ";
+      if (!dirBranch.isEmpty()) {
+         if (dirType=="T" || dirType=="N") {
+            command += "-r " + dirBranch + " ";
+         } else if (dirType=="D") {
+            command += "-D " + dirBranch + " ";
+         } else {
+            Debug::g_pLog->log(Debug::LL_THE_OLD_MAN_AND_THE_SEA,"unknown dirBranchType: ->"+dirType+"<-");
+         }
+      }
+      command += m_selectedFiles;
+      cmd = CVS_UPDATE_FILES_CMD;
+      break;
       }
       case OTHERFILE: {
-	 if (sticky) {
-	    command += " update ";
-	    if (!cvsParameter.isEmpty()) {
-	       command += cvsParameter + " ";
-	    }
-	    command += m_selectedFiles;
-	    cmd = CVS_UPDATE_FILES_CMD;
-	 } else {
-	    cvsRevertToRevFile(cvsParameter);
-	    return;
-	 }
-	 break;
+         if (sticky) {
+            command += " update ";
+            if (!cvsParameter.isEmpty()) {
+               command += cvsParameter + " ";
+            }
+            command += m_selectedFiles;
+            cmd = CVS_UPDATE_FILES_CMD;
+         } else {
+            cvsRevertToRevFile(cvsParameter);
+            return;
+         }
+         break;
       }
       case OPTIONSFILE: {
-	 QString dirBranch = m_dir->getDirTag();
-	 QString dirType = "";
-	 if (!dirBranch.isEmpty()) {
-	    dirType = dirBranch.left(1);
-	    dirBranch = dirBranch.mid(1);
-	 }
-	 if (!cvsRemoveOptionsOk(dirBranch,true)) {
-	    reject(false);
-	    return;
-	 }
-	 command += " update -A ";
-	 if (!dirBranch.isEmpty()) {
-	    if (dirType=="T" || dirType=="N") {
-	       command += "-r " + dirBranch + " ";
-	    } else if (dirType=="D") {
-	       command += "-D " + dirBranch + " ";
-	    } else {
-	       Debug::g_pLog->log(Debug::LL_THE_OLD_MAN_AND_THE_SEA,"unknown dirBranchType: ->"+dirType+"<-");
-	    }
-	 }
-	 command += m_selectedFiles;
-	 cmd = CVS_UPDATE_FILES_CMD;
-	 break;
+         QString dirBranch = m_dir->getDirTag();
+         QString dirType = "";
+         if (!dirBranch.isEmpty()) {
+            dirType = dirBranch.left(1);
+            dirBranch = dirBranch.mid(1);
+         }
+         if (!cvsRemoveOptionsOk(dirBranch,true)) {
+            reject(false);
+            return;
+         }
+         command += " update -A ";
+         if (!dirBranch.isEmpty()) {
+            if (dirType=="T" || dirType=="N") {
+               command += "-r " + dirBranch + " ";
+            } else if (dirType=="D") {
+               command += "-D " + dirBranch + " ";
+            } else {
+               Debug::g_pLog->log(Debug::LL_THE_OLD_MAN_AND_THE_SEA,"unknown dirBranchType: ->"+dirType+"<-");
+            }
+         }
+         command += m_selectedFiles;
+         cmd = CVS_UPDATE_FILES_CMD;
+         break;
       }
       case QUERYDIR: {
 	 command += " -n update ";
@@ -741,7 +741,7 @@ bool Update::cvsRemoveOptionsOk(QString dirBranch,bool fileCollection) {
 	 myChild = myChild->nextSibling();
       }
       if (!test) {
-	 showWarning( tr("Warning"), tr("There are tags set that would be removed too.\n"
+	 showWarning( tr("Warning"), tr("There are tags set that would also be removed.\n"
 		     "If this is what you want, run:\n"
 		     "'update other revision'\n"
 		     "with option 'reset sticky tag' selected") );
@@ -797,7 +797,6 @@ void Update::afterCall(int cmd,CvsBuffer * buf,bool failed) {
 	 break;
       }
       case CVS_UPDATE_FILES_CMD: {
-	 m_dir->removeTmpEntries();
 	 if (!m_dir->parseCallResult( buf, cmd)) {
 	    emit showWarning(tr("CVS Info"),m_dir->getLastError());
 	 }
