@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: UpdateOtherRevisionDialogImpl.cpp,v 1.29 2004/12/03 00:28:04 tilo Exp $
-**
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
 **    Falk Brettschneider <gigafalk@yahoo.com>
@@ -117,7 +115,11 @@ UpdateOtherRevisionDialogImpl::UpdateOtherRevisionDialogImpl(bool dirOnly, QStri
 {
 
   m_pWhatsThis->setIconSet(whatsThisIconSet);
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
   m_Revision->setValidator(new RevisionValidator(m_Revision));
   m_TagBox->setAutoCompletion(FALSE);
@@ -175,7 +177,7 @@ QString UpdateOtherRevisionDialogImpl::cvsParameter() {
 	}
 	if (m_Date->isEnabled()) {
 	  if (!param.isEmpty()) param += " ";
-	  param += "-D \"" + m_Date->dateTime().toString("yyyy-MM-dd hh:mm") + "\"";
+	  param += "-D " + masqWs(m_Date->dateTime().toString("yyyy-MM-dd hh:mm:ss"));
 	}
       }
     }
@@ -194,7 +196,7 @@ QString UpdateOtherRevisionDialogImpl::cvsParameter() {
       }
     }
     if (m_Date->isEnabled()) {
-      txt = m_Date->dateTime().toString("yyyy-MM-dd hh:mm");
+      txt = m_Date->dateTime().toString("yyyy-MM-dd hh:mm:ss");
       if (!txt.isEmpty()) {
 	param += ":"+txt;
       }
@@ -242,13 +244,14 @@ void UpdateOtherRevisionDialogImpl::okClicked() {
 }
 
 void UpdateOtherRevisionDialogImpl::showWarning() {
-  QString txt = tr("Updating without setting sticky tags is dangerous!")+"\n"
-    +tr("If no revision/tag is specified, the main trunk is assumed.")+"\n"
-    +tr("To make sure all files are reverted to exactly what you want")+"\n"
-    +tr("requires manually setting a regular tag and specifying this as")+"\n"
-    +tr("the tag to update to.")+"\n"
-    +tr("Carefully watch the cvs output and make sure")+"\n"
-    +tr("cvs really does what you want.");
+  QString txt = tr(
+    "Updating without setting sticky tags is dangerous!<br>"
+    "If no revision/tag is specified, the main trunk is assumed. "
+    "To make sure all files are reverted to exactly what you want "
+    "requires manually setting a regular tag and specifying this as "
+    "the tag to update to.<br>"
+    "Carefully watch the cvs output and make sure "
+    "cvs really does what you want.");
   QMessageBox::information(this,tr("Warning"),txt,QMessageBox::Ok);
 }
 
