@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: UpdateOtherRevisionStdDialogImpl.cpp,v 1.6 2004/12/03 00:28:04 tilo Exp $
-**
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
 **    Falk Brettschneider <gigafalk@yahoo.com>
@@ -102,7 +100,11 @@ UpdateOtherRevisionStdDialogImpl::UpdateOtherRevisionStdDialogImpl(bool dirOnly,
     m_stickyTagState(TRUE) {
 
   m_pWhatsThis->setIconSet(whatsThisIconSet);
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
   setCaption(caption);
   if (dirOnly) {
@@ -178,13 +180,14 @@ void UpdateOtherRevisionStdDialogImpl::setStickyTagToggled(bool state) {
 }
 
 void UpdateOtherRevisionStdDialogImpl::showWarning() {
-  QString txt = tr("Updating without setting sticky tags is dangerous!")+"\n"
-    +tr("If no revision/tag is specified, the main trunk is assumed.")+"\n"
-    +tr("To make sure all files are reverted to exactly what you want")+"\n"
-    +tr("requires manually setting a regular tag and specifying this as")+"\n"
-    +tr("the tag to update to.")+"\n"
-    +tr("Carefully watch the cvs output and make sure")+"\n"
-    +tr("cvs really does what you want.");
+  QString txt = tr(
+    "Updating without setting sticky tags is dangerous!<br>"
+    "If no revision/tag is specified, the main trunk is assumed. "
+    "To make sure all files are reverted to exactly what you want "
+    "requires manually setting a regular tag and specifying this as "
+    "the tag to update to.<br>"
+    "Carefully watch the cvs output and make sure "
+    "cvs really does what you want.");
   QMessageBox::information(this,tr("Warning"),txt,QMessageBox::Ok);
 }
 
