@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: WatchersDialogImpl.cpp,v 1.15 2004/09/21 09:07:52 tilo Exp $
-**
 ** Copyright (C) 2002-2004 Frank Hemer <frank@hemer.org>
 **
 **
@@ -101,7 +99,11 @@ WatchersDialogImpl::WatchersDialogImpl(const QIconSet &whatsThisIconSet,
     : WatchersDialog( LookAndFeel::g_b0AsParent ? 0 : parent, name, fl )
 {
   m_pWhatsThis->setIconSet(whatsThisIconSet);
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
   ButtonLayout->addWidget(new QSizeGrip(this),0,Qt::AlignRight|Qt::AlignBottom);
 
   WatchersList->setColumnAlignment(2,Qt::AlignHCenter);
