@@ -1,6 +1,4 @@
 /****************************************************************************
- **
- ** $Id: WrappersIgnoreDialogImpl.cpp,v 1.11 2004/10/06 00:07:55 frank Exp $
  **
  ** Copyright (C) 2001-2004 The LinCVS development team.
  **    Tilo Riemer <riemer@lincvs.org>
@@ -101,7 +99,11 @@ WrappersIgnoreDialogImpl::WrappersIgnoreDialogImpl( QStringList* src,
      m_pSrc(src),m_Caption(caption)
 {
    m_pWhatsThis->setIconSet(whatsThisIconSet);
-   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#ifdef Q_WS_MAC
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
+  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
 
    setCaption(m_Caption);
    m_GroupBox->setTitle(m_Caption);
