@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: aboutdialogimpl.cpp,v 1.20.2.1 2005/01/16 14:31:11 tilo Exp $
-**
 ** Copyright (C) 2001-2005 Tilo Riemer <riemer@lincvs.org>,
 **                         Frank Hemer <frank@hemer.org>,
 **                         Jose Hernandez <joseh@tesco.net>
@@ -154,7 +152,7 @@ void AboutDialogImpl::openBrowserBgu()
 void AboutDialogImpl::setAboutText()
 {
    QString text = "<html><br><br><br><br><p align=\"center\">";
-   text += tr("LinCVS - An user friendly CVS frontend");
+   text += tr("LinCVS - A user-friendly CVS front-end");
    text += "<br><br>";
    QString copyright = tr("Copyright (C) 1999 - %1 Tilo Riemer, Frank Hemer and others");
    text += copyright.arg(2005);
@@ -296,6 +294,14 @@ void AboutDialogImpl::setTranslatorText()
    text += tr("jcukeng from uinc.ru &lt;<u><font color=\"#5500ff\">jcukeng at gmx dot net</font></u>&gt;");
    text += "</p>";
 
+   text += "<h3>";
+   text += tr("Vietnamese");
+   text += "</h3>";
+
+   text += "<p>";
+   text += tr("Clytie Siddall &lt;<u><font color=\"#5500ff\">clytie at riverland dot net dot au</font></u>&gt;");
+   text += "</p>";
+
    text += "</html>";
 
    m_pTranslatorText->setText(text);
@@ -311,7 +317,7 @@ void AboutDialogImpl::setAckText()
    text += "<br>";
    text += tr("<b>Dave Knopp</b>");
    text += "<br>";
-   text += tr("<b>Peter Palfrader</b>, <b>Jason Friedrich</b> and <b>Frank Lichtenheld</b> for maintaining of the debian package");
+   text += tr("<b>Peter Palfrader</b>, <b>Jason Friedrich</b> and <b>Frank Lichtenheld</b> for maintaining the Debian package");
    text += "<br>";
    text += tr("<b>Soeren Staun-Pedersen</b> for hosting of the LinCVS mailing list at SunSITE.dk");
    text += "<br>";
@@ -319,11 +325,13 @@ void AboutDialogImpl::setAckText()
    text += "<br>";
    text += tr("<b>Raimar Lamprecht</b>, <b>Kelly John Carney</b> and <b>Will Stokes</b> for support of Mac OS X port");
    text += "<br>";
-   text += tr("<b>Andre Oliveira da Costa</b> and <b>Dag Wieers</b> for maintaining of RPM packages for Fedora/RedHat");
+   text += tr("<b>Andre Oliveira da Costa</b> and <b>Dag Wieers</b> for maintaining RPM packages for Fedora/RedHat");
    text += "<br>";
    text += tr("<b>Anja Landgraf</b> for the very nice poster");
    text += "<br>";
    text += tr("<b>Robert Hess</b> for the old logo icon");
+   text += "<br>";
+   text += tr("<b>Clytie Siddall</b> for improving the English translation and very good collaboration");
    text += "<br><br>";
    text += tr("Thanks to the people behind <b>Trolltech</b> for a very powerful toolkit and excellent support");
    text += "<br><br>";
