@@ -1,6 +1,6 @@
 /****************************************************************************
  **
- ** Copyright (C) 2003-2004 Frank Hemer <frank@hemer.org>,
+ ** Copyright (C) 2003-2005 Frank Hemer <frank@hemer.org>,
  **                         Tilo Riemer <riemer@lincvs.org>
  **
  **
@@ -356,7 +356,7 @@ bool CvsControl::addNewProject(const QString fileName, bool expand) {
 
       if ( fileName.mid(fileName.findRev("/")+1) == projectNameList[i]) {
 	 showWarning(tr("Warning")+", "+tr("adding aborted"),
-	       tr("This project is already in workbench:\n")
+	       tr("This project is already in the workbench:\n")
 	       +projectNameList[i]
 	       +"\nat: "+fullName);
 	 setStatusText( tr("Adding aborted"), 4000 );
@@ -783,6 +783,7 @@ void CvsControl::slot_rereadProject(DirBase * dir) {
 //----------------------------------------------------------------------------
 
 // reopen tree, returns deepest opened dir in hierarchy or null, if not found in workbench
+// it returns also null if dirToOpen is removed behind the back
 Directory * CvsControl::openTreeAt(const QString &topDirName,const QString &dirToOpen) {
 
    DirBase * dir = NULL;
@@ -798,8 +799,11 @@ Directory * CvsControl::openTreeAt(const QString &topDirName,const QString &dirT
    }
    dir = m_pWorkBenchTree->find( dirToOpen );
    if (dir) {
-      if (ONTHEFLYSCANNING) dir->setOpen(TRUE);//This will scan!
+      QString curDir = dir->fullName();
+      QString removed;
+      if (ONTHEFLYSCANNING) dir->setOpen(TRUE, removed);//This will scan!
       else dir->setAllOpen();
+      if (removed == curDir) dir = 0;
    }
    slot_checkStatusOfTree(static_cast<Directory *>(m_pWorkBenchTree->find(topDirName)));
    return static_cast<Directory *>(dir);
@@ -1186,12 +1190,14 @@ void CvsControl::readCurrentTagList() {
       return;
    }
    m_currentTagList.clear();
+   QString cvsRoot = "status -v";
    QString files;
    QStringList fileList = m_pFetchTagDir->getSelectedFiles();
+   masqQuoteMarks(&fileList);
    if (!fileList.isEmpty()) files = masqWs(fileList.join("\" \""));
+   else cvsRoot += " -l";
    
    QString dirName = m_pFetchTagDir->fullName();
-   QString cvsRoot = "status -v";
    QString topModule = m_pFetchTagDir->topControlledDir()->relativeName();
    callInteractiveCmd( topModule, dirName, cvsRoot,
 	 files, CVS_GET_TAG_INFO_FILES_CMD,
@@ -1244,13 +1250,14 @@ void CvsControl::editFile( QString FN) {
     
       QStringList::Iterator it;
       for (it=nameList.begin(); it != nameList.end(); it++) {
+         (*it).replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS);
 	 (*it) = dir->fullName()+"/"+(*it);
       }
       QString cmd = masqWs(item.app);
       QString params = " " + item.params;
       if (masqedFilenamesForPlaceholders(params,nameList)) {
-	 cmd += params;
-	 runExternal(cmd);
+         cmd += params;
+         runExternal(cmd);
       } else {
 	 showWarning(tr("Warning"), tr("There are no matching placeholders specified,")
 	       +"\n"
@@ -1279,6 +1286,7 @@ void CvsControl::viewFileWithPath( QString FN) {
     
       QStringList::Iterator it;
       for (it=nameList.begin(); it != nameList.end(); it++) {
+         (*it).replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS);
 	 (*it) = path+"/"+(*it);
       }
       QString cmd = masqWs(item.app);
@@ -1355,7 +1363,8 @@ void CvsControl::openFile()
       
 	 QStringList::Iterator it;
 	 for (it=nameList.begin(); it != nameList.end(); it++) {
-	    (*it) = dir->fullName()+"/"+(*it);
+            (*it).replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS);
+            (*it) = dir->fullName()+"/"+(*it);
 	 }
 	 QString cmd = masqWs(item.app);
 	 QString params = " " + item.params;
@@ -1394,7 +1403,8 @@ void CvsControl::viewFile()
       
 	 QStringList::Iterator it;
 	 for (it=nameList.begin(); it != nameList.end(); it++) {
-	    (*it) = dir->fullName()+"/"+(*it);
+            (*it).replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS);
+            (*it) = dir->fullName()+"/"+(*it);
 	 }
 	 QString cmd = masqWs(item.app);
 	 QString params = " " + item.params;
@@ -1494,12 +1504,16 @@ Directory * CvsControl::rereadProjectOfDir( Directory * dir ) {
 
    dir = (Directory *)m_pWorkBenchTree->find( dirToOpenAfterRescan );
    if( dir )  {
+      QString curDir = dir->fullName();
       QStringList::Iterator it;
       for (it = openDirs.begin(); it != openDirs.end(); ++it) {
-	 openTreeAt( topDirName, (*it));
+        Directory *openedDir = openTreeAt( topDirName, (*it));
+        if (!openedDir && (curDir == (*it))) dir = 0;
+      }
+      if (dir) {
+        m_pWorkBenchTree->setSelected( dir, TRUE );
+        dir->activateItem(FALSE);
       }
-      m_pWorkBenchTree->setSelected( dir, TRUE );
-      dir->activateItem(FALSE);
    }
    applyProjectSettings(moduleName);
    return dir;
@@ -1595,11 +1609,15 @@ void CvsControl::renameDir(Directory * dir,QString newName) {
 
    dir = static_cast<Directory *>(m_pWorkBenchTree->find(newName));
    if (dir) {
+      QString curDir = dir->fullName();
       for (it = openDirs.begin(); it != openDirs.end(); ++it) {
-	 openTreeAt( newName, (*it));
+        Directory *openedDir = openTreeAt( newName, (*it));
+        if (!openedDir && (curDir == (*it))) dir = 0;
+      }
+      if (dir) {
+        m_pWorkBenchTree->setSelected( dir, TRUE );
+        dir->activateItem(FALSE);
       }
-      m_pWorkBenchTree->setSelected( dir, TRUE );
-      dir->activateItem(FALSE);
    }
 }
 
@@ -1915,7 +1933,7 @@ void CvsControl::removeDirIfNoCvsRegisteredFiles() {
 
    if(!dir->loginOk(m_pMessages)) return;
 
-   if (!showVerifyDialog(tr("Warning"),tr("This command will recursive remove\nfile(s) from disk!"))) {
+   if (!showVerifyDialog(tr("Warning"),tr("This command will recursively remove\nfile(s) from disk!"))) {
       return;
    }
 
@@ -1976,12 +1994,21 @@ void CvsControl::exportFromModuleDir() {
       return;
    }
 
-   QFile file(exportDir);
-   if (file.exists()) {
-      if (!showYesNoQuestion(tr("Warning"),
-		  tr("The directory:") + " "
-		  + exportDir
-		  + " " + tr("already exists.") + "\n" + tr("Overwrite it?"))) return;
+   QDir exdir(exportDir);
+   if (exdir.exists()) {
+      QStringList entries = exdir.entryList();
+      bool bEmpty = true;
+      for (QStringList::Iterator it = entries.begin(); it != entries.end(); it++ ) {
+         if ( (*it == ".") || (*it == "..") ) continue;
+         bEmpty = false;
+         break;
+      }
+      if (!bEmpty) {
+         if (!showYesNoQuestion(tr("Warning"),
+            tr("The directory:") + " "
+            + exportDir
+            + " " + tr("already exists.") + "\n" + tr("Overwrite it?"))) return;
+      }
    }
 
    QApplication::setOverrideCursor(waitCursor);
@@ -2069,8 +2096,12 @@ void CvsControl::callInteractiveCmd( QString& topModule,
 	 cvsRootLine = textStream.readLine();
 	 f.close();
       }
+   } else {
+      int pos = cvsRootOrCommand.find("\"",1);//extract tmp files
+      if (pos > -1) cvsRootLine = cvsRootOrCommand.left(pos+1);
+      else cvsRootLine = cvsRootOrCommand;
+      cvsRootLine = umasqWs(cvsRootLine);//only umasq for local use, not for cmd call!!!
    }
-   else cvsRootLine = umasqWs(cvsRootOrCommand);//only umasq for local use, not for cmd call!!!
    if (!extractCVSROOT( cvsRootLine, method, user, passwd, host, port, rootDir)) {
       if (Debug::g_pLog) Debug::g_pLog->log(Debug::LL_THE_OLD_MAN_AND_THE_SEA,"ERROR in cvsRootLine: ->"+cvsRootLine+"<-");
       cvsCallFailed(icmd,instance);
@@ -2245,23 +2276,35 @@ void CvsControl::callInteractiveCmd( QString& topModule,
 
 	 Debug::g_pLog->log(Debug::LL_INFO, "access method: ext/ssh-agent");
 
-	 if (!sshAgentStarted) {
+	 sshAgentIsRunning = false;
+	 if (!sshAgentStarted || bUseSshAgentVars) {
 	    bool blocked = isGuiBlocked();
 	    if (!blocked) blockGUI(true);
-	    setStatusText(tr("Starting ssh-agent.  Please wait..."));
-	    startSshAgent();//(check for ssh agent variables if bUseSshAgentVars) and start ssh agent
+	    if (!bUseSshAgentVars) setStatusText(tr("Starting ssh-agent. Please wait ..."));
+	    startSshAgent();//(check for ssh agent variables if bUseSshAgentVars or start ssh agent
 	    if (!blocked) blockGUI(false);
-	    if (!sshAgentStarted) {
-	       setStatusText(tr("couldn't start Ssh-agent"));
+	    if (bUseSshAgentVars) {
+	       if (sshAgentIsRunning) {
+		  setStatusText(tr("Using running ssh-agent. Please wait ..."));
+	       } else if (sshAgentStarted) {
+		  setStatusText(tr("Couldn't detect running ssh-agent. Own agent started, please wait ..."));
+	       } else {
+		  setStatusText(tr("Cannot detect running ssh-agent and couldn't start agent, call canceled."));
+		  cvsCallFailed(icmd,instance);
+		  return;
+	       }
+	    } else if (!sshAgentStarted) {
+	       setStatusText(tr("Couldn't start ssh-agent"));
 	       cvsCallFailed(icmd,instance);
 	       return;
 	    } else {
-	       setStatusText(tr("Ssh-agent started.  Please wait..."));
+	       setStatusText(tr("Ssh-agent started. Please wait ..."));
 	    }
 	 }
-	    
-	 if (!sshAgentIsRunning) checkSshAgent();
+
+	 if (!sshAgentIsRunning) checkSshAgent();//read agent env vars
 	 if (!sshAgentIsRunning) {//cancel the command if ssh agent could not be started
+	    setStatusText(tr("Cannot detect running ssh-agent, call canceled."));
 	    cvsCallFailed(icmd,instance);
 	    return;
 	 }
