@@ -76,8 +76,6 @@
 
 #include "config.h"
 
-#include <qpixmap.h>
-
 #include "globals.h"
 #include "cmainwindow.h"
 #include "CvsBuffer.h"
@@ -88,12 +86,7 @@
 #include "Timer.h"
 
 class CvsDirListView;
-class CvsIgnoreListView;
-class NonCvsListView;
-class CvsListView;
 class Directory;
-class InteractiveCmdThread;
-class QListView;
 class ColorTabWidget;
 class CPixmapTimer;
 class cvsToolbar;
