@@ -1,8 +1,6 @@
 /****************************************************************************
  **
- ** $Id: cvslistview.cpp,v 1.90 2005/01/10 01:42:35 frank Exp $
- **
- ** Copyright (C) 2001-2004 The LinCVS development team.
+ ** Copyright (C) 2001-2005 The LinCVS development team.
  **    Tilo Riemer <riemer@lincvs.org>
  **    Falk Brettschneider <gigafalk@yahoo.com>
  **    Frank Hemer <frank@hemer.org>
@@ -381,10 +379,15 @@ void CvsDirListView::contentsMousePressEvent ( QMouseEvent * e )
       QPoint offset(10, 5);
       popupMenu( dirItem, mapToGlobal(contentsToViewport(e->pos())) + offset);
    } else {
+      bool sameDirClicked = false;
       if ( (dirItem == OldItem) && (!DirWatch::b_isActive) ) {
-	 emit dirClicked(dirItem);
+         sameDirClicked = true;
       }
+      bool open = dirItem->isOpen ();
       QListView::contentsMousePressEvent ( e );
+      if (sameDirClicked && (open == dirItem->isOpen ())) {
+         emit dirClicked (dirItem);
+      }
    }
    e->accept();
 }
