@@ -1,6 +1,4 @@
 /****************************************************************************
- **
- ** $Id: directory.cpp,v 1.271 2005/01/06 15:56:01 frank Exp $
  **
  ** Copyright (C) 1999-2004 The LinCVS development team.
  **    Tilo Riemer <riemer@lincvs.org>
@@ -290,6 +288,8 @@ Directory * Directory::createInstance(const QString& fileName)
 	 assert(false);
       }
    }
+
+   return 0; // makes the compiler happy
 }
 
 //----------------------------------------------------------------------------
@@ -324,6 +324,8 @@ Directory * Directory::createChildInstance( QListViewItem * parent,
 	 assert(false);
       }
    }
+
+   return 0; // makes the compiler happy
 }
 
 //----------------------------------------------------------------------------
@@ -820,11 +822,11 @@ void Directory::paintCell( QPainter *p, const QColorGroup &cg,
 //----------------------------------------------------------------------------
 
 //called after checkout, if it's a part of an existing project, and after UPDATE_DIR_CMD and QUERY_UPDATE_CMD
-//returns the first not jet analyzed directory in the hierarchy
+//returns the first not yet analyzed directory in the hierarchy
 //if addVirtual==true, add as virtual dir, itter, don't analyze!
 DirBase * Directory::addDir(QString newDir, bool addVirtual) {
 
-   if (!m_isAnalyzedDir && !m_virtual ) {//don't add if scanning hasn't reached this depth jet!
+   if (!m_isAnalyzedDir && !m_virtual ) {//don't add if scanning hasn't reached this depth yet!
       return this;
    }
 
@@ -888,40 +890,6 @@ DirBase * Directory::addDir(QString newDir, bool addVirtual) {
 
 //----------------------------------------------------------------------------
 
-Directory* Directory::searchDirOfRepository(QString repository) {
-   if(repository.compare(m_rootDir + "/" + m_repository) == 0)
-      return this;   //its my repository :-)
-
-   bool isSubDir = false;
-   if((m_repository.find(".")) == 0 && (m_repository.length() == 1)) {// . detected
-      if(repository.find(m_rootDir + "/") == 0) {//is subdir
-         isSubDir = true;
-      }
-   }
-   else {
-      if(repository.find(m_rootDir + "/" + m_repository) == 0) {//is subdir
-         isSubDir = true;
-      }
-   }
-
-   if(isSubDir) {//is subdir
-      Directory *myChild = firstChild();
-      Directory *result;
-      while(myChild) {
-         if( (result = myChild->searchDirOfRepository(repository)) ) {
-            return result;
-         }
-         else {
-            myChild = myChild->nextSibling();
-         }
-      }
-   }
-   
-   return 0;
-}
-
-//----------------------------------------------------------------------------
-
 DirBase * Directory::searchDirOfPath(QString path, bool findVirtual) {
    if (!findVirtual && m_virtual) {
       return NULL;
@@ -1304,6 +1272,13 @@ bool Directory::recCopyControlledFiles(QString nextDir, int writeMode /*=Create*
 	 qDebug("can't create dir: "+nextDir);
 	 return false;
       }
+   } else if (writeMode==Replace) {
+      if (!newDir.exists()) {
+	 if (!newDir.mkdir(nextDir)) {
+	    qDebug("can't create dir: "+nextDir);
+	    return false;
+	 }
+      }
    } else if (!newDir.exists()) {
       qDebug("dir doesn't exists: "+nextDir);
       return false;
@@ -1323,7 +1298,8 @@ bool Directory::recCopyControlledFiles(QString nextDir, int writeMode /*=Create*
 	    return false;
 	 }
 	 if ( (writeMode & (Overwrite|Replace)) && targetInfo.exists() && !targetInfo.isWritable()) {
-	    setPermission(target,READABLE|WRITEABLE|(targetInfo.isExecutable() ? EXECUTABLE : 0));
+            QFile targetFile(target);
+	    setPermission(targetFile,READABLE|WRITEABLE|(targetInfo.isExecutable() ? EXECUTABLE : 0));
 	 }
 
 	 QFileInfo info(source);
@@ -1347,7 +1323,8 @@ bool Directory::recCopyControlledFiles(QString nextDir, int writeMode /*=Create*
    if (writeMode & Replace) {//remove remaining files
       QStringList::Iterator iter = targetFiles.begin();
       while (iter!=targetFiles.end()) {
-	 setPermission(*iter,WRITEABLE);
+         QFile targetFile(*iter);
+	 setPermission(targetFile,WRITEABLE);
 	 if (!newDir.remove(*iter)) {
 	    qDebug("cannot remove file: "+nextDir+"/"+*iter);
 	 }
@@ -1960,7 +1937,7 @@ bool Directory::analyzeDirs() {
 	       m_hasControlledSubDir = true;
 	    }
 	    else if (item->isDisabled()) continue;
-	    else if (ONTHEFLYSCANNING && !item->isAnalyzed()) continue;//don't know jet if there are cvs dirs somewhere in depth
+	    else if (ONTHEFLYSCANNING && !item->isAnalyzed()) continue;//don't know yet if there are cvs dirs somewhere in depth
 	    else {
 	       delete item;
 	       item = 0; // paranoia
