@@ -1,6 +1,4 @@
 /****************************************************************************
- **
- ** $Id: directory.h,v 1.119 2005/01/06 14:48:42 frank Exp $
  **
  ** Copyright (C) 1999-2004 The LinCVS development team.
  **    Tilo Riemer <riemer@lincvs.org>
@@ -218,9 +216,6 @@ class Directory : public DirBase
    void setAutoUpdate(bool);
    void setCallTime(QDateTime &);
    
-   DirBase* searchDirOfPath(QString path, bool findVirtual = false);
-   DirBase* searchLastValidDirOfPath(QString path);
-   
    // Methods for state tracking
    void setFilesToUpToDate(QStringList& updateFileList);   
    void setAllToUpToDate();
@@ -253,6 +248,10 @@ class Directory : public DirBase
    virtual bool parseCallResult(CvsBuffer*, int, QStringList * =0) {return false;}
    virtual bool backupFiles(QStringList);
    virtual bool restoreFiles(QStringList);
+   virtual QStringList getControledSubdirs() {return QStringList();}
+   virtual DirBase * searchDirOfPath(QString path, bool findVirtual = false);
+   virtual DirBase * searchLastValidDirOfPath(QString path);
+   
    
    //functions telling about cvs file state
    virtual bool isControlled(QString) {return false;}
@@ -295,7 +294,6 @@ class Directory : public DirBase
    void init(const QString& fileName);
 
    void setAndAppendEntry(QString&, EntryStates);
-   Directory* searchDirOfRepository(QString repository);
    
    // state bubble up
    void setDirState( EntryStates, bool fromChild = false);
