@@ -1,8 +1,6 @@
 /****************************************************************************
  **
- ** $Id: globals.cpp,v 1.149.2.2 2005/01/16 14:29:35 tilo Exp $
- **
- ** Copyright (C) 1999-2004 Tilo Riemer <riemer@lincvs.org> and
+ ** Copyright (C) 1999-2005 Tilo Riemer <riemer@lincvs.org> and
  **    Frank Hemer <frank@hemer.org>
  **    Wim Delvaux <wim.delvaux@chello.be>
  **    Jose Hernandez <joseh@tesco.net>
@@ -85,6 +83,7 @@
 #include <sys/stat.h>
 #include <stdlib.h>
 #include <time_ac.h>
+#include <unistd.h>
 
 //----------------------------------------------------------------------------
 
@@ -103,11 +102,6 @@
 #include <qmessagebox.h>
 #include <qregexp.h>
 
-#ifdef Q_WS_MAC
-#define USE_TM_GMTOFF
-#endif
-#include <unistd.h>
-
 //----------------------------------------------------------------------------
 
 #include "globals.h"
@@ -131,7 +125,7 @@
 
 //----------------------------------------------------------------------------
 
-int sshPid;
+int sshPid = -1;
 
 //----------------------------------------------------------------------------
 
@@ -378,7 +372,7 @@ bool removeFromCvsPassFile( QString cvsRoot) {
 
 //----------------------------------------------------------------------------
 
-int extractCVSROOT( QString rootline,
+bool extractCVSROOT( QString rootline,
       QString& method,
       QString& user,
       QString& passwd,
@@ -387,15 +381,22 @@ int extractCVSROOT( QString rootline,
       QString& path) {
 
    /* Access method specified, as in
-    * "cvs -d :(gserver|kserver|pserver):[[user][:password]@]host[:[port]]/path",
-    * "cvs -d [:(ext|server):][[user]@]host[:]/path",
-    * "cvs -d :local:e:\path",
-    * "cvs -d :fork:/path".
+    * "cvs -d :(gserver|kserver|pserver)[;params...]:[[[user][:password]@]host[:[port]]]/path",
+    * "cvs -d [:(ext|server)[;params...]:][[[user]@]host[:]]/path",
+    * "cvs -d :local[;params...]:e:\path",
+    * "cvs -d :fork[;params...]:/path".
     *
     * Note that path for connecting to a cvs-winnt server might be something like:
     * "/d//somepath/cvs"
     */
 
+   method = QString::null;
+   user = QString::null;
+   passwd = QString::null;
+   host = QString::null;
+   port = -1;
+   path = QString::null;
+
    int from, to;
    int atpos;
    QString tmpStr;
@@ -407,6 +408,35 @@ int extractCVSROOT( QString rootline,
       if (to == -1) return false;//syntax error
       method = rootline.mid((unsigned int)from,(unsigned int)(to-from));
       rootline = rootline.mid((unsigned int)(to+1));
+
+      //extract additional options, separated by ';'
+      QStringList optList = QStringList::split(";", method);
+      method = optList[0];
+      QStringList::Iterator it = optList.begin();
+      while (++it != optList.end()) {
+	 int pos = (*it).find('=');
+	 if (pos > -1) {
+	    QString keyword = (*it).left(pos);
+	    QString value = (*it).mid(pos+1);
+	    if (keyword == "username" || keyword == "user") {
+	       user = value;
+	    } else if (keyword == "password" || keyword == "pass") {
+	       passwd = value;
+	    } else if (keyword == "hostname" || keyword == "host") {
+	       host = value;
+	       if (port == -1) port = 2401;
+	    } else if (keyword == "port") {
+	       port = value.toInt();
+	    } else if (keyword == "directory" || keyword == "path") {
+	       path = value;
+	    } else {
+	       qDebug("ignoring CVSROOT option: '"+keyword+"="+value+"'");
+	    }
+	 } else {
+	    qDebug("Invalid option in CVSROOT: '"+(*it));
+	 }
+      }
+
    } else if ( (rootline.at((unsigned int)0) != '/') && (rootline.contains('/')) ) {
       method = "ext";
    } else {
@@ -416,10 +446,6 @@ int extractCVSROOT( QString rootline,
    if ( (method == "local") || (method == "fork")) {
       if ( rootline.find(':') > 1) return false;
       path = rootline;
-      user = QString::null;
-      passwd = QString::null;
-      host = QString::null;
-      port = -1;
       return true;
    }
 
@@ -452,37 +478,35 @@ int extractCVSROOT( QString rootline,
 	 if (user.isEmpty()) user = getenv("USER");
       } else {
 	 user = rootline.mid((unsigned int)0,(unsigned int)atpos);
-	 passwd = QString::null;
       }
       if (user.isEmpty()) return false;//no user
-   } else {
-      user = QString::null;
-      passwd = QString::null;
    }
    rootline = rootline.mid((unsigned int)(atpos+1));
 
 
    //host:port
-   from = rootline.find(':');
-   to = rootline.find(':',from+1);
-   if (from == -1) {
-      host = rootline;
-      port = 2401;
-   } else if (to == -1) {
-      tmpStr = rootline.mid((unsigned int)(from+1));
-      if (tmpStr.isEmpty()) {
+   if (host.isNull()) {
+      from = rootline.find(':');
+      to = rootline.find(':',from+1);
+      if (from == -1) {
+	 host = rootline;
 	 port = 2401;
+      } else if (to == -1) {
+	 tmpStr = rootline.mid((unsigned int)(from+1));
+	 if (tmpStr.isEmpty()) {
+	    port = 2401;
+	 } else {
+	    port = tmpStr.toInt();
+	 }
       } else {
-	 port = tmpStr.toInt();
+	 port = rootline.mid((unsigned int)(from+1),(unsigned int)(to-from-1)).toInt();
       }
-   } else {
-      port = rootline.mid((unsigned int)(from+1),(unsigned int)(to-from-1)).toInt();
+      host = rootline.mid((unsigned int)0,(unsigned int)from);
    }
-   host = rootline.mid((unsigned int)0,(unsigned int)from);
-
 
    if (host.isEmpty()) return false;//no host
    if (port == 0) return false;//no number ie. syntax error
+
    return true;
 }
 
@@ -549,41 +573,58 @@ void startSshAgent() {
 	 useAgent = false;
       }
       if (useAgent) {
-	 sshAgentStarted = true;
 	 sshAgentIsRunning = true;
-	 sshPid = -1;//don't kill agent on exit
+	 return;
+      } else if (sshPid > 0) {
 	 return;
       }
    }
 
-   QString sh = APPDIR + "/" + LC_TOOLS_DIR + "/start-ssh-agent.sh";
+   QString sh = ExtApps::g_sshAgent.path;
+   if (!sh.startsWith("/")) {
+      sh = APPDIR + "/" + LC_TOOLS_DIR + "/" + sh;
+   }
+   QString options = ExtApps::g_sshAgent.options;
+   masqedFilenamesForPlaceholders(options, ExtApps::g_sshKeyFiles);
+   QStringList args = QStringList::split("\" \"",umasqWs(options));
+   args.prepend(sh);
+
+#ifdef Q_WS_MAC
+   QString askpass = APPDIR + "/" + LC_TOOLS_DIR + "/ssh-askpass.app/Contents/MacOS/ssh-askpass";
+#else
    QString askpass = APPDIR + "/" + LC_TOOLS_DIR + "/ssh-askpass.bin";
+#endif
 
    QStringList * env = NULL;
-   sshProc = new QProcess(sh);
+   sshProc = new QProcess();
+   sshProc->setArguments(args);
 
    if (QFileInfo(askpass).exists()) {
-      env = new QStringList();
-      QString tmpEnv;
-      QString tmpVar;
-      tmpVar = "DISPLAY";
-      tmpEnv = getenv(tmpVar);
-      if (tmpEnv.length() != 0) {
-	 env->append(tmpVar+"="+tmpEnv);
-      }
-      tmpVar = "PATH";
-      tmpEnv = getenv(tmpVar);
-      if (tmpEnv.length() != 0) {
-	 env->append(tmpVar+"="+tmpEnv);
-      }
-      tmpVar = "HOME";
-      tmpEnv = getenv(tmpVar);
-      if (tmpEnv.length() != 0) {
-	 env->append(tmpVar+"="+tmpEnv);
-      }
-      env->append("SSH_ASKPASS="+askpass);
+	   env = new QStringList();
+	   QString tmpEnv;
+	   QString tmpVar;
+	   tmpVar = "DISPLAY";
+	   tmpEnv = getenv(tmpVar);
+	   if (tmpEnv.length() > 0) {
+		   env->append(tmpVar+"="+tmpEnv);
+#ifdef Q_WS_MAC
+	   } else {
+		   env->append(tmpVar+"=:0.0");
+#endif
+	   }
+	   tmpVar = "PATH";
+	   tmpEnv = getenv(tmpVar);
+	   if (tmpEnv.length() != 0) {
+		   env->append(tmpVar+"="+tmpEnv);
+	   }
+	   tmpVar = "HOME";
+	   tmpEnv = getenv(tmpVar);
+	   if (tmpEnv.length() != 0) {
+		   env->append(tmpVar+"="+tmpEnv);
+	   }
+	   env->append("SSH_ASKPASS="+askpass);
    }
-
+   
    if (sshProc->start(env)) {
       while (sshProc->isRunning()) {
 	 wait(100);
@@ -614,7 +655,7 @@ void checkSshAgent() {
 
    f.setName(QDir::homeDirPath() + "/.ssh/lincvs-environment");
    
-   sshPid = -1;
+   int tPid = -1;
    sshAuthSock = "";
   
    if(f.open(IO_ReadOnly)) {//file is readable
@@ -639,17 +680,22 @@ void checkSshAgent() {
 	    }
 	    QString pid = tmp.left(ch_pos);
 	    envSSH_AGENT_PID = "SSH_AGENT_PID="+pid;
-	    sshPid = pid.toInt();
+	    tPid = pid.toInt();
 	 } else if(line.contains("_AGENT_PID=") > 0) {//SSH or SSH2
 	    envSSH_AGENT_PID = line.left(line.find(";"));
 	    QString pid = envSSH_AGENT_PID.mid(envSSH_AGENT_PID.find("=")+1);
-	    sshPid = pid.toInt();
+	    tPid = pid.toInt();
 	 }
       }
    }   
   
-   if (sshPid > 0 && (!envSSH_AUTH_SOCK.isEmpty())) sshAgentIsRunning = true;
-   else sshAgentIsRunning = false;  //sshPid not found, should never happen
+   if (tPid > 0 && (!envSSH_AUTH_SOCK.isEmpty())) {
+      if (sshPid == -1) sshPid = tPid;
+      sshAgentIsRunning = true;
+   } else {
+      killSshAgent();
+      sshAgentIsRunning = false;
+   }
 }
 
 //----------------------------------------------------------------------------
@@ -658,7 +704,11 @@ void killSshAgent() {
    if (sshPid > 0) {
       QString pid;
       pid.setNum(sshPid);
-      system("kill " + pid);
+      if (system("kill " + pid)) qDebug("kill ssh agent pid: "+QString::number(sshPid)+" failed");
+      QString fileName = QDir::homeDirPath() + "/.ssh/lincvs-environment";
+      if (!QFile::remove(fileName)) {
+	 qDebug("Kill ssh agent: couldn't remove environment:\n"+fileName);
+      }
       sshAgentIsRunning = false;
       sshAgentStarted = false;
       sshPid = -1;
@@ -778,7 +828,7 @@ void createTmpDir()
 
 QString createTempFile(QString appendix /*= QString::null*/)
 {
-   if (!appendix.isNull()) appendix.replace(QRegExp("[\\/<>&]"),"_");
+   if (!appendix.isNull()) appendix.replace(QRegExp("[\\/<>&\"]"),"_");
     
    QString tmp = tmpDir + "/tmp.XXXXXX";
 
@@ -864,9 +914,9 @@ QString createHistoryFile()
 void runExternal( QString arg, QDir *dir) {
 
    arg = LW::validateEchse(arg);
-   QString debugStr = "running: "+arg+" in: ";
-   if (dir) debugStr += dir->absPath();
-   else debugStr += "default dir";
+   QString debugStr = "running: " + arg + " in";
+   if (dir) debugStr += ": " + dir->absPath();
+   else debugStr += " default dir: "+QDir::currentDirPath();
    qDebug(debugStr);
    arg += " ";
 
@@ -905,7 +955,10 @@ void runExternal( QString arg, QDir *dir) {
 	 if ( (tmp.endsWith("\"")) || (tmp.endsWith("'")) ) {
 	    tmp = tmp.left(tmp.length()-1);
 	 }
-	 if (!tmp.isEmpty()) args.append (tmp);
+	 if (!tmp.isEmpty()) {
+            tmp.replace(PLACEHOLDER_FOR_QUOTATION_MARKS, "\"");
+            args.append (tmp);
+         }
 	 lastPos = i+1;
       }
    }
@@ -1036,6 +1089,17 @@ QString umasqWs(QString str) {
 
 //----------------------------------------------------------------------------
 
+void masqQuoteMarks(QStringList *pList)
+{
+   QStringList::Iterator it = pList->begin();
+   while (it != pList->end()) {
+      (*it).replace("\"", PLACEHOLDER_FOR_QUOTATION_MARKS);
+      it++;
+   }
+}
+
+//----------------------------------------------------------------------------
+
 Mapping::FileAppItem getMatchForWildcard(const QStringList& nameList, const Mapping::FileAppList& appList) {
 
    QRegExp rx;
@@ -1204,11 +1268,16 @@ QString getProxy(const QString& userAtHost) {
 
 //----------------------------------------------------------------------------
 
-void wait( int msecs) {
+void wait(int usecs) {
+
+#ifdef NANOSLEEP
    struct timespec req;
-   req.tv_sec = 0;
-   req.tv_nsec = msecs*1000;
+   req.tv_sec  =  usecs / 1000000;
+   req.tv_nsec = (usecs % 1000000) * 1000;
    nanosleep(&req,NULL);
+#else
+   usleep(usecs);
+#endif
 }
 
 //----------------------------------------------------------------------------
