@@ -1,8 +1,6 @@
 /****************************************************************************
 **
-** $Id: globals.h,v 1.124.2.2 2005/01/16 14:29:35 tilo Exp $
-**
-** Copyright (C) 1999-2004 Tilo Riemer <riemer@lincvs.org>,
+** Copyright (C) 1999-2005 Tilo Riemer <riemer@lincvs.org>,
 **                         Frank Hemer <frank@hemer.org>,
 **                         Jose Hernandez <joseh@tesco.net>,
 **                         Tom Mishima <tmishima@mail.at-m.or.jp>,
@@ -149,6 +147,8 @@ const int USESSHAGENTVARS  = 3;
 const QString DEFDIRPOPUPMENU  = "29:17:27:11:26:35:0:31:37:26:13:14:26:8:33:10:26:9:6:25:23:26:19:21:20:26:16:26:2:";
 const QString DEFFILEPOPUPMENU = "30:18:28:12:26:15:4:5:26:36:1:32:38:26:7:34:26:24:22:26:3:";
 
+const char PLACEHOLDER_FOR_QUOTATION_MARKS[] = "^^^^^";
+
 //----------------------------------------------------------------------------
 
 class CvsConfig;
@@ -225,11 +225,14 @@ namespace ExtApps {
       QString options;
    };
    
+   EXTERN App g_sshAgent;
    EXTERN App g_localShell;
    EXTERN App g_localBrowser;
    EXTERN App g_remoteBrowser;
    EXTERN App g_cvsRsh;
    EXTERN App g_diffProg;
+
+   EXTERN QStringList g_sshKeyFiles;
 }
 
 namespace DirWatch {
@@ -474,7 +477,7 @@ extern int     analyzeCVSROOT( QString& method,
       int& port,
       QString& path);
 
-extern int     extractCVSROOT( QString rootline,
+extern bool     extractCVSROOT( QString rootline,
       QString& method,
       QString& user,
       QString& passwd,
@@ -526,6 +529,7 @@ extern void cutList(QStringList* pList, int allowedSize);
 //masque filenames containing whitespaces for use with InteractiveCmdThread
 extern QString masqWs(const QString &str);
 extern QString umasqWs(QString str);
+extern void masqQuoteMarks(QStringList *pList);
 
 //validation of passed command line options
 extern QString validateOptions(const QString options);
@@ -545,8 +549,8 @@ extern bool rename(const QString& src, const QString& dst);
 //proxy
 extern QString getProxy(const QString& userAtHost);
 
-//wait
-extern void wait(int msecs);
+//wait for usecs micro seconds
+extern void wait(int usecs);
 
 //system linefeed
 extern QString getSystemLF();
