@@ -1,7 +1,5 @@
 /****************************************************************************
 **
-** $Id: login.cpp,v 1.31 2004/10/11 12:59:22 frank Exp $
-**
 ** Copyright (C) 2001-2004 Frank Hemer <frank@hemer.org>
 **
 **----------------------------------------------------------------------------
@@ -419,26 +417,28 @@ void Login::error( int err) {
 
 void Login::appendCvsPassEntry(QString *pwd) {
    QString cvsroot;
+   QString cvsPassPath;
    if (CVSVERSION == "cvsnt") {
       cvsroot = ":pserver:"+m_user+"@"+m_host+":"+QString::number(m_port)+":"+m_dir;
+      cvsPassPath = QDir::homeDirPath()+"/.cvs/cvspass";
    } else {
       cvsroot = ":pserver:"+m_user+"@"+m_host+":"+QString::number(m_port)+m_dir;
+      cvsPassPath = CVSPASSPATH;
    }
    bool res = writeToCvsPassFile(cvsroot,*pwd);
    if (!res) {
-      pMessages->append("Couldn't append: "+cvsroot+" to "+CVSPASSPATH+"\n");
+      pMessages->append ("Couldn't append: "+cvsroot+" to "+cvsPassPath+"\n");
+      Debug::g_pLog->log (Debug::LL_INFO, "Couldn't append: "+cvsroot+" to "+cvsPassPath);
       pMessages->append("Check if you have required rw permissions (0600 is required on unix systems)\n");
-      Debug::g_pLog->log(Debug::LL_INFO, "Couldn't append: "+cvsroot+" to "+CVSPASSPATH);
    } else {
-      pMessages->append("Added: "+cvsroot+" to registered loggins\n");
-      Debug::g_pLog->log(Debug::LL_INFO, "Added: "+cvsroot+" to registered loggins");
-      
+      pMessages->append ("Added: "+cvsroot+" to registered loggins\n");
+      Debug::g_pLog->log (Debug::LL_INFO, "Added: "+cvsroot+" to registered loggins");
       //appending of entry with port number succeeded...
       if (m_port == 2401) {//add an entry without port number for old cvs versions
          cvsroot = ":pserver:"+m_user+"@"+m_host+":"+m_dir;
          bool res = writeToCvsPassFile(cvsroot,*pwd);
          if (!res) {//adding failed --> and now? At the moment a log entry is enough
-            Debug::g_pLog->log(Debug::LL_INFO, "Couldn't append: "+cvsroot+" to "+CVSPASSPATH);
+            Debug::g_pLog->log(Debug::LL_INFO, "Couldn't append: "+cvsroot+" to "+cvsPassPath);
          }
       }
    }
