@@ -110,6 +110,7 @@
 #include "TextCodec.h"
 #include "TextDecoder.h"
 #include "TextEncoder.h"
+#include "SshKeyDialogImpl.h"
 
 //----------------------------------------------------------------------------
 
@@ -121,7 +122,10 @@
 
 SettingsDialogImpl::SettingsDialogImpl(const QIconSet &whatsThisIconSet, 
       QWidget* parent,  const char* name, bool, WFlags fl)
-   : SettingsDialog(parent, name, true, fl)
+   : SettingsDialog(parent, name, true, fl),
+     m_onTheFlyScanningModeChanged(false),
+     m_agentSetupChanged(false),
+     m_dialogUp(false)
 {
    m_pWhatsThis->setIconSet(whatsThisIconSet);
   
@@ -130,7 +134,11 @@ SettingsDialogImpl::SettingsDialogImpl(const QIconSet &whatsThisIconSet,
    //m_pWhatsThis->setMaximumWidth(QIconSet::iconSize(QIconSet::Small).width() + margin);
 
    // simple solution --> the whatsthis icon should be not wider than high
+#ifdef Q_WS_MAC
+   m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height() * 2);
+#else
    m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());
+#endif
   
    // Set value on GUI to current compresion level
    m_CompressionLevel->setValue(CvsOptions::g_compression);
@@ -152,6 +160,11 @@ SettingsDialogImpl::SettingsDialogImpl(const QIconSet &whatsThisIconSet,
    //set module update timer value
    AutoUpdateSpinBox->setValue(AUTOUPDATEINTERVALL);
 
+   // set ssh agent
+   m_sshKeyFiles = ExtApps::g_sshKeyFiles;
+   m_SshAgent->setText(ExtApps::g_sshAgent.path);
+   m_SshAgentOptions->setText(ExtApps::g_sshAgent.options);
+
    // set remote shell
    m_RemoteShell->setText(ExtApps::g_cvsRsh.path);
 
@@ -173,7 +186,6 @@ SettingsDialogImpl::SettingsDialogImpl(const QIconSet &whatsThisIconSet,
    m_pHistorySizeProfiles->setValue(HistorySize::g_workdirs);
   
    // set on the fly scanning mode
-   m_onTheFlyScanningModeChanged = false;
    m_onTheFlyScanning->setChecked(ONTHEFLYSCANNING);
 
    // set default r/rw permission for files on checkout/update
@@ -362,6 +374,7 @@ SettingsDialogImpl::SettingsDialogImpl(const QIconSet &whatsThisIconSet,
 
    m_pUseAutoUpdate->setChecked(AUTOUPDATE);
 
+   m_dialogUp = true;
 }
 
 //----------------------------------------------------------------------------
@@ -407,6 +420,20 @@ void SettingsDialogImpl::apply()
    // set update check level
    Polling::checkStatusLevel = CheckStatusSpinBox->value();
 
+   // ssh agent
+   if (ExtApps::g_sshKeyFiles != m_sshKeyFiles) {
+      m_agentSetupChanged = true;
+      ExtApps::g_sshKeyFiles = m_sshKeyFiles;
+   }
+   if (ExtApps::g_sshAgent.path != m_SshAgent->text()) {
+      m_agentSetupChanged = true;
+      ExtApps::g_sshAgent.path = m_SshAgent->text();
+   }
+   if (ExtApps::g_sshAgent.options != m_SshAgentOptions->text()) {
+      m_agentSetupChanged = true;
+      ExtApps::g_sshAgent.options = m_SshAgentOptions->text();
+   }
+
    // Remote shell
    ExtApps::g_cvsRsh.path = m_RemoteShell->text();
 
@@ -754,6 +781,42 @@ bool SettingsDialogImpl::isOnTheFlyScanningModeChanged() {
 
 //----------------------------------------------------------------------------
 
+bool SettingsDialogImpl::isAgentSetupChanged() {
+   return m_agentSetupChanged;
+}
+
+//----------------------------------------------------------------------------
+
+void SettingsDialogImpl::maintainKeyClicked() {
+   SshKeyDialogImpl * dlg = new SshKeyDialogImpl(m_sshKeyFiles,
+	 *(m_pWhatsThis->iconSet()),
+	 tr("Maintain ssh keys"),
+	 this,
+	 "",
+	 true,
+	 LookAndFeel::g_modalF);
+   dlg->exec();
+   delete dlg;
+}
+
+//----------------------------------------------------------------------------
+
+void SettingsDialogImpl::browseSshAgentCmd()
+{
+   /* Using the Qt standard file dialog preserves the look and feel
+    * of the application across platforms.
+    */
+   QString fn = QFileDialog::getOpenFileName (m_SshAgent->text(), NULL, this, 0,
+	 tr("Choose ssh agent"),
+	 NULL, true);
+
+   if ( !fn.isEmpty() ) {
+      m_SshAgent->setText(fn);
+   }
+}
+
+//----------------------------------------------------------------------------
+
 void SettingsDialogImpl::browseLocalBrowserCmd()
 {
    /* Using the Qt standard file dialog preserves the look and feel
