@@ -104,6 +104,7 @@ class SettingsDialogImpl : public SettingsDialog
    ~SettingsDialogImpl();
 
    bool isOnTheFlyScanningModeChanged();
+   bool isAgentSetupChanged();
 
  signals:
    void setFonts();
@@ -135,11 +136,13 @@ class SettingsDialogImpl : public SettingsDialog
    void showColorDlgDiffOld();
    void showColorDlgDiffNew();
 
+   void browseSshAgentCmd();
    void browseLocalBrowserCmd();
    void browseLocalShellCmd();
    void browseRemoteBrowserCmd();
    void browseRemoteShellCmd();
    void browseExternalDiffCmd();
+   void maintainKeyClicked();
 
    void chooseFontGeneral();
    void chooseFontMessage();
@@ -164,6 +167,9 @@ class SettingsDialogImpl : public SettingsDialog
    void applyLangEnv();
    
    bool m_onTheFlyScanningModeChanged;
+   bool m_agentSetupChanged;
+   bool m_dialogUp;
+   QStringList m_sshKeyFiles;
 
    QColor m_colorFileA;
    QColor m_colorFileB;
